@@ -24,7 +24,7 @@ class Check_table(object): # classe de vérification des données entrée dans l
                           self.syrthesIHMCollector.Periodicity_2D_form.Per_2D_tra_table : ['', 'float', 'float', '+compintstr', '+compintstr', ''], # Tableau de la périodicité en translation en 2D
                           self.syrthesIHMCollector.Periodicity_3D_form.Per_3D_rot_table : ['', 'float', 'float', 'float', 'float', 'float', 'float', 'angle', '+compintstr', '+compintstr', ''], # Tableau de la périodicité en rotation en 3D
                           self.syrthesIHMCollector.Periodicity_3D_form.Per_3D_tra_table : ['', 'float', 'float', 'float', '+compintstr', '+compintstr', ''], # Tableau de la périodicité en translation en 3D
-                          self.syrthesIHMCollector.Spectral_parameters_form.Rp_Sb_table : ['', '+int', 'spfloat', 'spfloat2', ''], # Tableau des définitions des bandes spectrales
+                          self.syrthesIHMCollector.Spectral_parameters_form.Rp_Sb_table : ['', '+chkintstr', 'spfloat', 'spfloat2', ''], # Tableau des définitions des bandes spectrales
                           self.syrthesIHMCollector.View_factor_2D_form.Vf_Ip_2D_table : ['', 'float', 'float', ''], # Tableau des coordonnées de points pour les facteurs de forme en 2D
                           self.syrthesIHMCollector.View_factor_2D_form.Vf_Sy_2D_table : ['', 'float', 'float', 'float', ''], # Tableau des symétries pour les facteurs de forme en 2D
                           self.syrthesIHMCollector.View_factor_2D_form.Vf_Pe_2D_table : ['', 'float', 'float', 'angle', ''], # Tableau des periodicités pour les facteurs de forme en 2D
@@ -41,9 +41,18 @@ class Check_table(object): # classe de vérification des données entrée dans l
                           self.syrthesIHMCollector.Initial_conditions_hum_TPvPt_form.Vch_Ic_TPvPt_table : ['', '', '', 'cond2float', '+chkintstr', ''], # Tableau des conditions volumique en humidité modèle 3 équations
                           self.syrthesIHMCollector.Volumetric_conditions_hum_TPv_form.Vch_St_TPv_table : ['', '', '', 'cond2float', 'cond2float', '+chkintstr', ''], # Tableau des termes sources en humidité modèle 2 équations
                           self.syrthesIHMCollector.Volumetric_conditions_hum_TPvPt_form.Vch_St_TPvPt_table : ['', '', '', 'cond2float', 'cond2float', '+chkintstr', ''], # Tableau des termes sources en humidité modèle 3 équations
-                          self.syrthesIHMCollector.Material_humidity_properties_form.Mhp_table : ['', '', '+chkintstr', ''], # Tableau des propriété matériaux en humidité
+                          self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_iso_2D_table : ['', '', '+chkintstr', ''], # Tableau des propriété matériaux en humidité
+                          self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_iso_3D_table : ['', '', '+chkintstr', ''], # Tableau des propriété matériaux en humidité
+                          self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_aniso_2D_table : ['', '', 'float', '+chkintstr', ''], # Tableau des propriété matériaux en humidité
+                          self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_aniso_3D_table : ['', '', 'float','float','float','float','float','float','float','float','float','+chkintstr', ''], # Tableau des propriété matériaux en humidité
                           self.syrthesIHMCollector.Boundary_conditions_TPv_form.Bc_TPv_table : ['', '', 'float>-273.15Combo', 'cond+=float', 'cond+=float', 'cond+=float', 'cond+=float', '+chkpintstr', ''], # Tableau des conditions aux limites en humidité modèle 2 équations
                           self.syrthesIHMCollector.Boundary_conditions_TPvPt_form.Bc_TPvPt_table : ['', '', 'float>-273.15Combo', 'cond+=float', 'cond+=float', 'cond+=float', 'cond+=float', 'cond+=float', 'cond+=float', '+chkpintstr', ''], # Tableau des conditions aux limites en humidités modèle 3 équations
+
+
+                          self.syrthesIHMCollector.Contact_resistance_humidity_TPv_form.Cont_res_hum_TPv_table : ['', '', 'float>-273.15Combo', 'cond+=float', '+compintstr', '+compintstr', ''], # Tableau des resistances de contact en humidité modèle 2 équations
+                          self.syrthesIHMCollector.Contact_resistance_humidity_TPvPt_form.Cont_res_hum_TPvPt_table : ['', '', 'float>-273.15Combo', 'cond+=float', 'cond+=float', '+compintstr', '+compintstr', ''], # Tableau des resistances de contact en humidités modèle 3 équations
+
+
                           self.syrthesIHMCollector.Output_2D_form.Op_Dc_2D_table : ['', 'float', 'float', ''], # Tableau des définitions par coordonnés en 2D dans les sorties
                           self.syrthesIHMCollector.Output_3D_form.Op_Dc_3D_table : ['', 'float', 'float', 'float', ''], # Tableau des définitions par coordonnés en 3D dans les sorties
                           self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Sc_table : ['', 'stringContinu', '+chkintstr', ''], # Tableau du couplage surfacique pour le transfert de chaleur conjugué
@@ -52,7 +61,27 @@ class Check_table(object): # classe de vérification des données entrée dans l
                           self.syrthesIHMCollector.Output_3D_form.Op_Sb_3D_table : ['', '+intstr', ''], # Tableau des bilans surfaciques 3D
                           self.syrthesIHMCollector.Output_2D_form.Op_Sb_2D_table : ['', '+intstr', ''], # Tableau des bilans surfaciques 2D
                           self.syrthesIHMCollector.Output_3D_form.Op_Vb_3D_table : ['', '+intstr', ''], # Tableau des bilans volumiques 3D
-                          self.syrthesIHMCollector.Output_2D_form.Op_Vb_2D_table : ['', '+intstr', '']} # Tableau des bilans volumiques 2D
+                          self.syrthesIHMCollector.Output_2D_form.Op_Vb_2D_table : ['', '+intstr', ''], # Tableau des bilans volumiques 2D
+                          # fluid1d
+                          self.syrthesIHMCollector.Geometrie_fluid1d_form.Geom_fluid1d_table : ['', '+float', '+float', '+=float', '+chkintstr',''], # Tableau de la geometrie fluide 1D
+                          self.syrthesIHMCollector.Initial_conditions_fluid1d_form.Init_TV_table : ['', '', 'float>-273.15Combo', 'condfloat', '+chkintstr',''], # Tableau de la conditions initiales fluide 1D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Inlet_3D_table : ['', '', 'float', 'float', 'float', 'condfloat', 'float>-273.15Combo', ''], # Tableau de la Inlet fluide 1D en 3D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Heat_ex_table : ['', '', 'float>-273.15Combo', 'cond+float', '+chkintstr', ''], # Tableau de la Heat Exchange fluide 1D en 3D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Flux_cond_table : ['', '', 'condfloat', '+chkintstr', ''], # Tableau de la Flux condition fluide 1D en 3D
+                          self.syrthesIHMCollector.Physical_prop_fluid1d_form.Prop_fluid1d_table : ['', '', 'cond+float', 'cond+float', 'cond+float', 'cond+float', '+chkintstr', ''], #Tableau de la Physical Proprieties fluide 1D
+                          self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Source_fluid1d_table : ['', '', 'condfloat', 'condfloat', '+chkintstr', ''],# Tableau de la Volumetric source fluide 1D
+                          self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Linear_head_fluid1d_table : ['', '', 'cond+float', '+chkintstr', ''], # Tableau de la Linear head losses fluide 1D
+                          self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Singular_head_fluid1d_table : ['', '', 'cond+float', '+chkintstr', ''], # Tableau de la Singular head losses fluide 1D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_cl : ['', '', 'float', 'float', 'float', 'cond+float', 'cond+float', 'cond+float', 'condfloat', ''], # Tableau de la Closed Lopp fluide 1D en 3D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_th_cl : ['', '', 'float', 'float', 'float', ''],# Tableau de la Thermal Closed Loop fluide 1D en 3D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_table_DP : ['', '', 'float', 'float', 'float', 'condfloat', 'condfloat', 'float>-273.15Combo' , ''],# Tableau pour Delta Pressure fluide 1D en 3D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Coupling_table : ['', '', '+float','+chkintstr' , ''],# Tableau pour Delta Pressure fluide 1D en 3D
+                          # fluid0d
+                          self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table : ['', '+chkintstr', '+float', '+chkintstr',''], # Tableau de la geometrie fluide 0D
+                          self.syrthesIHMCollector.Boundary_conditions_fluid0d_form.Heat_ex_fluid0d_table : ['','','cond+float','+chkintstr',''], # Tableau de conditions aux limites fluid0d
+                          self.syrthesIHMCollector.Physical_properties_fluid0d_form.Prop_fluid0d_table : ['','', 'volume+int','cond+float','cond+float', 'float>-273.15Combo',''], # Tableau des propriétés physiques d'un volume fluid0d                        
+                          self.syrthesIHMCollector.Volumetric_conditions_fluid0d_form.Volumetric_conditions_fluid0d_table : ['','', 'volume+int', 'cond+float', 'cond+float',''] # Tableau des conditions couplage 1d                        
+                          } 
                           
         Red=QtGui.QBrush(QtGui.QColor(255, 170, 127))
         self.Red = Red
@@ -124,6 +153,16 @@ class Check_table(object): # classe de vérification des données entrée dans l
                     if table.item(a,b) != None : 
                         if table.item(a,b).background() != self.Black :
                             self.checkPFloat(table, a, b)
+            elif chtype=='+=float': # Vérification pour les types de données flottant strictement supérieur à 0
+                if type(table.cellWidget(a, 0)) == QCheckBox :
+                    if table.cellWidget(a, 0).isChecked() :
+                        if table.item(a,b) != None : 
+                            if table.item(a,b).background() != self.Black :
+                                self.checkPEFloat(table, a, b)
+                else :
+                    if table.item(a,b) != None : 
+                        if table.item(a,b).background() != self.Black :
+                            self.checkPEFloat(table, a, b)
             elif chtype=='0<=float<=1' : # Vérification pour les types de données flottant compris entre 0<x<=1
                 if table.cellWidget(a, 0).isChecked() :
                     if table.item(a,b) != None : 
@@ -256,6 +295,18 @@ class Check_table(object): # classe de vérification des données entrée dans l
                 if table.cellWidget(a, 0).isChecked() :
                     if table.item(a,b) != None :        
                         self.checkBandInt(table, a, b)                 
+            elif chtype=='volume+int': # Vérification pour les types de données entier strictement positif comparé aux volumes 0D + '+chkpintstr'               
+                self.cellsList = []
+                for i in range(table.rowCount()) :
+                    if table.cellWidget(i, 0).isChecked() :
+                        if table.item(i,b) != None : 
+                            if table.item(i,b).background() != self.Black :
+                                self.cellsList.append([i,b])
+                for cell in self.cellsList :
+                    self.checkPIntstr(table, cell[0], cell[1])
+                if table.cellWidget(a, 0).isChecked() :
+                    if table.item(a,b) != None :        
+                        self.checkVolumeInt(table, a, b)
             elif chtype=='float>-273.15Combo': # Vérification pour les types de données flottant strictement supérieur à -273.15
                 # 'float>-273.15Combo' est toujours accompagné d'un combobox
                 if table.cellWidget(a, 0).isChecked() :
@@ -649,7 +700,7 @@ class Check_table(object): # classe de vérification des données entrée dans l
         else :
             i=0
             while i<self.syrthesIHMCollector.Spectral_parameters_form.Rp_Sb_table.rowCount():
-                if self.syrthesIHMCollector.Spectral_parameters_form.Rp_Sb_table.item(i,1)!=None:
+                if self.syrthesIHMCollector.Spectral_parameters_form.Rp_Sb_table.item(i,1)!=None and self.syrthesIHMCollector.Spectral_parameters_form.Rp_Sb_table.cellWidget(i, 0).isChecked()==True :
                     if table.item(a,b).text()==self.syrthesIHMCollector.Spectral_parameters_form.Rp_Sb_table.item(i,1).text():
                         flag=True
                         break
@@ -667,6 +718,31 @@ class Check_table(object): # classe de vérification des données entrée dans l
             table.item(a,b).setBackground(self.White)
             table.item(a,b).setToolTip('')
             
+    def checkVolumeInt(self, table, a, b): # Vérification pour les types de données entier strictement positif comparé aux bandes spectrales        
+        flag=False
+        if table.item(a,b).text()=='' :
+            flag = True
+        else :
+            i=0
+            while i<self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table.rowCount():
+                if self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table.item(i,1)!=None and self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table.cellWidget(i, 0).isChecked()==True:
+                    if table.item(a,b).text()==self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table.item(i,1).text():
+                        flag=True
+                        break
+                i=i+1
+        
+        if flag==False :               
+            table.blockSignals(True)
+            table.item(a,b).setBackground(self.Red)
+            errmes="Please enter a volume already defined in Geometry table"
+            table.item(a,b).setToolTip(errmes)
+            self.errflag=True
+            self.Errorcallback(errmes,table)                
+        else:    
+            table.blockSignals(True)                
+            table.item(a,b).setBackground(self.White)
+            table.item(a,b).setToolTip('')
+            
     def checkIntstrNotComp(self, table, a, b): # Vérification pour les types de données chaîne d'entiers strictement supérieur à 0 non comparé avec d'autres cellules
         line=-1
         stritem=str(table.item(a,b).text().toUtf8()).split()
