@@ -24,6 +24,8 @@ def StatusTip(self, parent=None):
                 self.syrthesIHMCollector.Home_form.Ho_Tr_ch : "Activation of complex radiation module (use 'help/What's this' for details)",#radio bouton pour le rayonnement
                 self.syrthesIHMCollector.Home_form.Ho_Hm_ch : "Activation of complex humidity module (use 'help/What's this' for details)",#radio bouton pour l'humidité
                 self.syrthesIHMCollector.Home_form.Ho_Ch_ch : "Activation of conjugate heat transfer option (use 'help/What's this' for details)",#radio bouton pour le transfert de chaleur
+                self.syrthesIHMCollector.Home_form.Ho_fluid1d_ch : "Activation of module 1D fluid flow option (use 'help/What's this' for details)",#radio bouton pour le module CDF 1D
+                self.syrthesIHMCollector.Home_form.Ho_fluid0d_ch : "Activation of module 0D fluid flow option (use 'help/What's this' for details)",#radio bouton pour le module CDF 0D
                 #Control_form
                 self.syrthesIHMCollector.Control_form.Ch_res_cal : "Restart calculation (use 'help/What's this' for details)",#checkbox de la reprise de calcul
                 self.syrthesIHMCollector.Control_form.lineEdit_39 : "Value of the new restart time (use 'help/What's this' for details)",#champ éditable du temp de reprise
@@ -32,6 +34,8 @@ def StatusTip(self, parent=None):
                 self.syrthesIHMCollector.Control_form.Le_auto_It : "Initial time step (use 'help/What's this' for details)",#champ éditable du temp initial
                 self.syrthesIHMCollector.Control_form.Le_auto_Mt : "Maximal temperature variation between two time steps (use 'help/What's this' for details)",#champ éditable de la variation de température maximum
                 self.syrthesIHMCollector.Control_form.Le_auto_Mts : "Upper bound for the allowed time step (use 'help/What's this' for details)",#champ éditable du pas de temp maximum
+                self.syrthesIHMCollector.Control_form.Le_auto_Mpv : "Maximal vapor pressure variation between two time steps (use 'help/What's this' for details)",#champ éditable de la variation de pression de vapeur maximum,
+                self.syrthesIHMCollector.Control_form.Le_auto_Mpt : "Maximal air pressure variation between two time steps (use 'help/What's this' for details)",#champ éditable de la variation de pression d'air maximum,
                 self.syrthesIHMCollector.Control_form.Le_const_Ts : "Time step value (use 'help/What's this' for details)",#champ éditable du pas de temp
                 self.syrthesIHMCollector.Control_form.By_Block_table : "Time steps per block (use 'help/What's this' for details)",#tableau des pas de temp par block
                 self.syrthesIHMCollector.Control_form.lineEdit_43 : "Solver precision (use 'help/What's this' for details)",#champ éditable de la précision du solver
@@ -83,6 +87,7 @@ def StatusTip(self, parent=None):
                 self.syrthesIHMCollector.Running_options_form.Ro_Ln_pb : "Activate file selection window",#bouton de choix de fichier listing
                 self.syrthesIHMCollector.Running_options_form.Ro_Cr_cb : "Option for results format translation",#combobox de la conversion de résultat
                 self.syrthesIHMCollector.Running_options_form.Ro_Dp_cb : "Mesh partitionning (already done or not)",#combobox du positionnement de domaine
+                self.syrthesIHMCollector.Running_options_form.Ro_Pre_cb : "Preprocessing for 1D Fluid (already done or not)",#combobox de preprocessing pour le fluid 1D
 ##                    self.syrthesIHMCollector.Solar_aspect_form.spinBox_4 : "79",#spinbox du nombre de processeur
 ##                    self.Ro_Pre_cb : "80",#checkbox de l'utilisation d' outils de pre-processing
 ##                    self.Ro_If_cb : "81",#checkbox de l'utilisation de fonctions interpretées
@@ -156,6 +161,10 @@ def StatusTip(self, parent=None):
                 self.syrthesIHMCollector.Boundary_conditions_TPv_form.Bc_TPv_table : "Table defining boundary conditions for Temperature T and Vapor pressure Pv",#tableau des conditions au limite TPv
                 #Boundary_conditions_TPvPt_form
                 self.syrthesIHMCollector.Boundary_conditions_TPvPt_form.Bc_TPvPt_table : "Table defining boundary conditions for Temperature T Vapor pressure Pv and total pressure Pt (use 'help/What's this' for details)",#tableau des conditions au limite TPvPt
+                #Boundary_conditions_TPv_form
+                self.syrthesIHMCollector.Contact_resistance_humidity_TPv_form.Cont_res_hum_TPv_table : "Table defining contact resistance for Temperature T and Vapor pressure Pv",#tableau des resistances de contact TPv
+                #Boundary_conditions_TPvPt_form
+                self.syrthesIHMCollector.Contact_resistance_humidity_TPvPt_form.Cont_res_hum_TPvPt_table : "Table defining contact resistance for Temperature T Vapor pressure Pv and total pressure Pt (use 'help/What's this' for details)",#tableau des resistances de contacts TPvPt
                 #Volumetric_conditions_hum_TPv_form
                 self.syrthesIHMCollector.Initial_conditions_hum_TPv_form.Vch_Ic_TPv_table : "Initial condition for Temperature T  and Vapor Pressure Pv (use 'help/What's this' for details)",#tableau des conditions initial TPv
                 self.syrthesIHMCollector.Volumetric_conditions_hum_TPv_form.Vch_St_TPv_table : "Source term for Temperature T and Vapor pressure Pv (use 'help/What's this' for details)",#tableau des termes sources TPv
@@ -163,7 +172,10 @@ def StatusTip(self, parent=None):
                 self.syrthesIHMCollector.Initial_conditions_hum_TPvPt_form.Vch_Ic_TPvPt_table : "Initial conditions for temperature T Vapor pressure Pv and totale pressure Pt (use 'help/What's this' for details)",#tableau des conditions initial TPvPt
                 self.syrthesIHMCollector.Volumetric_conditions_hum_TPvPt_form.Vch_St_TPvPt_table : "Source terms for temperature T vapor pressure Pv and totale pressure Pt (use 'help/What's this' for details)",#tableau des termes sources TPvPt
                 #Material_humidity_properties_form
-                self.syrthesIHMCollector.Material_humidity_properties_form.Mhp_table : "Table to select materials in an existing SYRTHES material library (use 'help/What's this' for details)",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_iso_2D_table : "Table to select materials in an existing SYRTHES material library (use 'help/What's this' for details)",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_aniso_2D_table : "Table to select materials in an existing SYRTHES material library (use 'help/What's this' for details)",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_iso_3D_table : "Table to select materials in an existing SYRTHES material library (use 'help/What's this' for details)",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_aniso_3D_table : "Table to select materials in an existing SYRTHES material library (use 'help/What's this' for details)",#tableau des propriétés des matériaux en humidité
                 #Conjugate heat transfer
                 self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Sc_table : "Table defining surface coupling with CFD codes (use 'help/What's this' for details)",
                 self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Vc_table : "Table defining volumic coupling with CFD codes (use 'help/What's this' for details)",
@@ -181,8 +193,11 @@ def StatusTip(self, parent=None):
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_ray_but : "c file specific for radiation (use 'help/What's this' for details)",# bouton user C function pour le rayonnement
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_hmt_lne : "c file specific for humidity models (use 'help/What's this' for details)", # bouton user C function pour la humidité
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_hmt_but : "c file specific for humidity models (use 'help/What's this' for details)", # bouton user C function pour la humidité
+                self.syrthesIHMCollector.User_C_function_form.Cfunc_fluid1d_lne : "c file specific for 1D fluid flow (use 'help/What's this' for details)",# bouton user C function pour cfd1d
+                self.syrthesIHMCollector.User_C_function_form.Cfunc_fluid1d_but : "c file specific for 1D fluid flow (use 'help/What's this' for details)",# bouton user C function pour cfd1d
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_other_lne : "c files specific to users (use 'help/What's this' for details)", # mode avancé
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_other_but : "c files specific to users (use 'help/What's this' for details)", # mode avancé
+                self.syrthesIHMCollector.User_C_function_form.Cfunc_test_compile : "Test compilation of user files (use 'help/What's this' for details)" ,
                 self.syrthesIHMCollector.Advanced_mode_form.Advanced_cmd_table : "Advanced user mode to define SYRTHES keywords and values (use 'help/What's this' for details)",# mode avancé
                 # Output
                 self.syrthesIHMCollector.Output_2D_form.Tf_cb_2D_Op : "Choice for the 2D field results (use 'help/What's this' for details)", 
@@ -201,6 +216,12 @@ def StatusTip(self, parent=None):
                 self.syrthesIHMCollector.Output_3D_form.Op_Dc_3D_table : "Table to specify the location of probes (in m) - use 'help/What's this' for details", 
                 self.syrthesIHMCollector.Output_3D_form.Op_Sb_3D_table : "Heat Balance through some surfaces identified by surface references (use 'help/What's this' for details)", 
                 self.syrthesIHMCollector.Output_3D_form.Op_Vb_3D_table : "Volume Heat Balance in domains identified by element references (use 'help/What's this' for details)",
+                self.syrthesIHMCollector.Output_3D_form.Hf_cb_3D_Op : "Choice for heat flux field results",
+                self.syrthesIHMCollector.Output_3D_form.Mt_cb_3D_Op : "Choice for maximal temperature field results",
+                self.syrthesIHMCollector.Output_3D_form.F_cb_3D_Op : "Choice for 3D fields results",
+                self.syrthesIHMCollector.Output_2D_form.Hf_cb_2D_Op : "Choice for heat flux field results",
+                self.syrthesIHMCollector.Output_2D_form.Mt_cb_2D_Op : "Choice for maximal temperature field results",
+                self.syrthesIHMCollector.Output_2D_form.F_cb_2D_Op : "Choice for 3D fields results",
                 self.syrthesIHMCollector.Home_form.Ho_Ds_te : "User description of the case (use 'help/What's this' for details)",
                 self.syrthesIHMCollector.Solar_aspect_form.Sa_chb : "Activate solar models (use 'help/What's this' for details)",
                 #self.verticalLayout : "verticalLayout",
@@ -214,7 +235,35 @@ def StatusTip(self, parent=None):
                 #self.Cb_Top2 : "Cb_Top2", 
                 #self.Cb_Top3 : "Cb_Top3",
                 #self.Cb_Top4 : "Cb_Top4"
-                } 
+
+                #fluid1d
+                self.syrthesIHMCollector.Initial_conditions_fluid1d_form.Init_TV_table : "1D fluid Initial temperature and velocity (use 'help/What's this' for details)", #tableau des temperature et vitesse initiales
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Heat_ex_table : "1D fluid Heat exchange table (use 'help/What's this' for details)", #tableau de l'échange de chaleur
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Flux_cond_table : "1D fluid Flux table (use 'help/What's this' for details)", #tableau de la condition du flux
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Inlet_3D_table : "1D fluid Inlet 3D table (use 'help/What's this' for details)", #tableau Inlet 3D
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_cl : "1D fluid Closed loop table (use 'help/What's this' for details)",
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_th_cl : "1D fluid Closed loop table (use 'help/What's this' for details)",
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_table_DP : "1D fluid Delta Pressure table (use 'help/What's this' for details)",
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Coupling_table : "Solid faces couples with 1D fluid table (set -1 to select all references)",
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_1df_lne : "References of 1D fluid faces coupled with conduction (use 'help/What's this' for details)",#champ d'édition du fluide 1D des faces
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_1dfUc_lne : "User comments allowing to mention detailed information (text only)",#champ d'édition User comments du fluide 1D des faces
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Prop_fluid1d_table : "1D fluid properties table (use 'help/What's this' for details)", # tableau des proprietes du fluide
+                self.syrthesIHMCollector.Geometrie_fluid1d_form.Geom_fluid1d_table : "1D fluid geometrie table (use 'help/What's this' for details)", # tableau pour la geometrie pour fluid1d
+                self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Source_fluid1d_table : "1D fluid source term table (use 'help/What's this' for details)", # tableau terme source fluid1d
+                self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Linear_head_fluid1d_table : "1D fluid linear head losses table (use 'help/What's this' for details)", # tableau perte de charge reguliere fluid1d
+                self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Singular_head_fluid1d_table : "1D fluid singular head losses table (use 'help/What's this' for details)", # tableau perte de charge singuliere fluid1d
+                self.syrthesIHMCollector.Control_fluid1d_form.Le_const_Ts_fluid1d : "1D fluid time step value (use 'help/What's this' for details)",#champ éditable du pas de temp FLUIDE 1D
+                self.syrthesIHMCollector.Control_fluid1d_form.Cb_solid_Ts_fluid1d : "Set 1D fluid time step value to solid time step", #checkbox pour indiquer que le pas de temps FLUIDE 1D est egal au pas de temps solide
+                self.syrthesIHMCollector.Filename_form.Fn_fluid1d_lne : "1D fluid mesh file",
+                self.syrthesIHMCollector.Filename_form.Fn_fluid1d_but : "Activate file selection window",
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Le_Gravity_x : "Gravity X",
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Le_Gravity_y : "Gravity Y",
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Le_Gravity_z : "Gravity Z",
+                self.syrthesIHMCollector.Boundary_conditions_fluid0d_form.Heat_ex_fluid0d_table : "0D fluid Boundary Conditions(use 'help/What's this' for details)",
+                self.syrthesIHMCollector.Physical_properties_fluid0d_form.Prop_fluid0d_table : "0D fluid Physical properties (use 'help/What's this' for details)",
+                self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table : "0D fluid geometrie table (use 'help/What's this' for details)", # tableau pour la geometrie pour fluid0d
+                self.syrthesIHMCollector.Volumetric_conditions_fluid0d_form.Volumetric_conditions_fluid0d_table : "0D volumetric conditions (use 'help/What's this' for details)"
+               } 
 
     for wid in self.widget:
         wid.setStatusTip(QtGui.QApplication.translate("MainWindow", self.dic_status[wid], None, QtGui.QApplication.UnicodeUTF8))
