@@ -47,11 +47,16 @@ def Table_callback(self, parent=None):
     self.connect(self.syrthesIHMCollector.Solar_aspect_form.Sa_Sm_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Boundary_conditions_TPv_form.Bc_TPv_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Boundary_conditions_TPvPt_form.Bc_TPvPt_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Contact_resistance_humidity_TPvPt_form.Cont_res_hum_TPvPt_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Contact_resistance_humidity_TPv_form.Cont_res_hum_TPv_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Initial_conditions_hum_TPvPt_form.Vch_Ic_TPvPt_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Volumetric_conditions_hum_TPvPt_form.Vch_St_TPvPt_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Initial_conditions_hum_TPv_form.Vch_Ic_TPv_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Volumetric_conditions_hum_TPv_form.Vch_St_TPv_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
-    self.connect(self.syrthesIHMCollector.Material_humidity_properties_form.Mhp_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_iso_2D_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_aniso_2D_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_iso_3D_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_aniso_3D_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Boundary_conditions_TPv_form.Bc_TPv_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Boundary_conditions_TPvPt_form.Bc_TPvPt_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Sc_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
@@ -62,7 +67,26 @@ def Table_callback(self, parent=None):
     self.connect(self.syrthesIHMCollector.Output_3D_form.Op_Vb_3D_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Output_2D_form.Op_Vb_2D_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
     self.connect(self.syrthesIHMCollector.Advanced_mode_form.Advanced_cmd_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
-
+    # fluid1d
+    self.connect(self.syrthesIHMCollector.Initial_conditions_fluid1d_form.Init_TV_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Heat_ex_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Flux_cond_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Inlet_3D_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_cl, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_th_cl, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_table_DP, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Coupling_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Physical_prop_fluid1d_form.Prop_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Geometrie_fluid1d_form.Geom_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Source_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Linear_head_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Singular_head_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    # fluid0d
+    self.connect(self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid0d_form.Heat_ex_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Physical_properties_fluid0d_form.Prop_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid0d_form.Volumetric_conditions_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.setupHheader)
+    
     # fonction de rappel permettant de lancé le contrôle des données entrées dans les tableaux
     self.connect(self.syrthesIHMCollector.Control_form.By_Block_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Control_form.By_Block_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
@@ -137,12 +161,27 @@ def Table_callback(self, parent=None):
     self.connect(self.syrthesIHMCollector.Boundary_conditions_TPv_form.Bc_TPv_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Boundary_conditions_TPv_form.Bc_TPv_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Boundary_conditions_TPvPt_form.Bc_TPvPt_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+
+    self.connect(self.syrthesIHMCollector.Contact_resistance_humidity_TPv_form.Cont_res_hum_TPv_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Contact_resistance_humidity_TPv_form.Cont_res_hum_TPv_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Contact_resistance_humidity_TPvPt_form.Cont_res_hum_TPvPt_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Contact_resistance_humidity_TPvPt_form.Cont_res_hum_TPvPt_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+
+
     self.connect(self.syrthesIHMCollector.Output_2D_form.Op_Dc_2D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Output_2D_form.Op_Dc_2D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Output_3D_form.Op_Dc_3D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Output_3D_form.Op_Dc_3D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
-    self.connect(self.syrthesIHMCollector.Material_humidity_properties_form.Mhp_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
-    self.connect(self.syrthesIHMCollector.Material_humidity_properties_form.Mhp_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_iso_2D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_iso_2D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_aniso_2D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_aniso_2D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_iso_3D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_iso_3D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_aniso_3D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_aniso_3D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+
     self.connect(self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Sc_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Sc_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Vc_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
@@ -157,7 +196,43 @@ def Table_callback(self, parent=None):
     self.connect(self.syrthesIHMCollector.Output_3D_form.Op_Vb_3D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Output_2D_form.Op_Vb_2D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
     self.connect(self.syrthesIHMCollector.Output_2D_form.Op_Vb_2D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
-
+    # fluid1d
+    self.connect(self.syrthesIHMCollector.Geometrie_fluid1d_form.Geom_fluid1d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Geometrie_fluid1d_form.Geom_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Initial_conditions_fluid1d_form.Init_TV_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Initial_conditions_fluid1d_form.Init_TV_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Inlet_3D_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Inlet_3D_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Heat_ex_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Heat_ex_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Flux_cond_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Flux_cond_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_cl, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_cl, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_th_cl, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_th_cl, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_table_DP, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_table_DP, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Coupling_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Coupling_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Physical_prop_fluid1d_form.Prop_fluid1d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Physical_prop_fluid1d_form.Prop_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Source_fluid1d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Source_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Linear_head_fluid1d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Linear_head_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Singular_head_fluid1d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Singular_head_fluid1d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    # fluid0d
+    self.connect(self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid0d_form.Heat_ex_fluid0d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Boundary_conditions_fluid0d_form.Heat_ex_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Physical_properties_fluid0d_form.Prop_fluid0d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Physical_properties_fluid0d_form.Prop_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid0d_form.Volumetric_conditions_fluid0d_table, SIGNAL("currentItemChanged(QTableWidgetItem *,QTableWidgetItem *)"), self.Check_table)
+    self.connect(self.syrthesIHMCollector.Volumetric_conditions_fluid0d_form.Volumetric_conditions_fluid0d_table, SIGNAL("cellChanged(int,int)"), self.Check_table)
+    
     # Fonction de rappel permettant de garder les propriétés physiques lors de passage entre 3D et 2D
     #self.connect(self.syrthesIHMCollector.Physical_prop_3D_form.Iso_cond_3D_table, SIGNAL("cellChanged(int,int)"), self.copyPropPhy)
     #self.connect(self.syrthesIHMCollector.Physical_prop_2D_form.Iso_cond_2D_table, SIGNAL("cellChanged(int,int)"), self.copyPropPhy)
