@@ -24,6 +24,8 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Home_form.Ho_Tr_ch : "Ho_Tr_ch",#radio bouton pour le rayonnement
                 self.syrthesIHMCollector.Home_form.Ho_Hm_ch : "Ho_Hm_ch",#radio bouton pour l'humidité
                 self.syrthesIHMCollector.Home_form.Ho_Ch_ch : "Ho_Ch_ch",#radio bouton pour le transfert de chaleur
+                self.syrthesIHMCollector.Home_form.Ho_fluid1d_ch : "Ho_fluid1d_ch",#radio bouton pour le module CFD1D
+                self.syrthesIHMCollector.Home_form.Ho_fluid0d_ch : "Ho_fluid0d_ch",#radio bouton pour le module CFD0D
                 #Control_form
                 self.syrthesIHMCollector.Control_form.Ch_res_cal : "Ch_res_cal",#checkbox de la reprise de calcul
                 self.syrthesIHMCollector.Control_form.lineEdit_39 : "lineEdit_39",#champ éditable du temp de reprise
@@ -32,6 +34,8 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Control_form.Le_auto_It : "Le_auto_It",#champ éditable du temp initial
                 self.syrthesIHMCollector.Control_form.Le_auto_Mt : "Le_auto_Mt",#champ éditable de la variation de température maximum
                 self.syrthesIHMCollector.Control_form.Le_auto_Mts : "Le_auto_Mts",#champ éditable du pas de temp maximum
+                self.syrthesIHMCollector.Control_form.Le_auto_Mpv : "Le_auto_Mpv",#champ éditable de la variation de pression de vapeur maximum,
+                self.syrthesIHMCollector.Control_form.Le_auto_Mpt : "Le_auto_Mpt",#champ éditable de la variation de pression d'air maximum,
                 self.syrthesIHMCollector.Control_form.Le_const_Ts : "Le_const_Ts",#champ éditable du pas de temp
                 self.syrthesIHMCollector.Control_form.By_Block_table : "By_Block_table",#tableau des pas de temp par block
                 self.syrthesIHMCollector.Control_form.lineEdit_43 : "lineEdit_43",#champ éditable de la précision du solver
@@ -87,6 +91,7 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Running_options_form.Ro_Ln_pb : "Ro_Ln_pb",#bouton de choix de fichier listing
                 self.syrthesIHMCollector.Running_options_form.Ro_Cr_cb : "Ro_Cr_cb",#combobox de la conversion de résultat
                 self.syrthesIHMCollector.Running_options_form.Ro_Dp_cb : "Ro_Dp_cb",#combobox du positionnement de domaine
+                self.syrthesIHMCollector.Running_options_form.Ro_Pre_cb : "Ro_Pre_cb",#combobox de l'utilisation du pre-processing
 ##                    self.syrthesIHMCollector.Solar_aspect_form.spinBox_4 : "79",#spinbox du nombre de processeur
 ##                    self.Ro_Pre_cb : "80",#checkbox de l'utilisation d' outils de pre-processing
 ##                    self.Ro_If_cb : "81",#checkbox de l'utilisation de fonctions interpretées
@@ -156,6 +161,10 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Boundary_conditions_TPv_form.Bc_TPv_table : "Bc_TPv_table",#tableau des conditions au limite TPv
                 #Boundary_conditions_TPvPt_form
                 self.syrthesIHMCollector.Boundary_conditions_TPvPt_form.Bc_TPvPt_table : "Bc_TPvPt_table",#tableau des conditions au limite TPvPt
+                #Contact_resistance_humidity_TPv_form
+                self.syrthesIHMCollector.Contact_resistance_humidity_TPv_form.Cont_res_hum_TPv_table : "Cont_res_hum_TPv_table",#tableau des resistances de contact TPv
+                #Contact_resistance_humidity_TPvPt_form
+                self.syrthesIHMCollector.Contact_resistance_humidity_TPvPt_form.Cont_res_hum_TPvPt_table : "Cont_res_hum_TPvPt_table",#tableau des resistances de contact TPvPt
                 #Volumetric_conditions_hum_TPv_form
                 self.syrthesIHMCollector.Initial_conditions_hum_TPv_form.Vch_Ic_TPv_table : "Vch_Ic_TPv_table",#tableau des conditions initial TPv
                 self.syrthesIHMCollector.Volumetric_conditions_hum_TPv_form.Vch_St_TPv_table : "Vch_St_TPv_table",#tableau des termes sources TPv
@@ -163,7 +172,10 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Initial_conditions_hum_TPvPt_form.Vch_Ic_TPvPt_table : "Vch_Ic_TPvPt_table",#tableau des conditions initial TPvPt
                 self.syrthesIHMCollector.Volumetric_conditions_hum_TPvPt_form.Vch_St_TPvPt_table : "Vch_St_TPvPt_table",#tableau des termes sources TPvPt
                 #Material_humidity_properties_form
-                self.syrthesIHMCollector.Material_humidity_properties_form.Mhp_table : "Mhp_table",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_iso_2D_table : "Mhp_iso_2D_table",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_2D_form.Mhp_aniso_2D_table : "Mhp_aniso_2D_table",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_iso_3D_table : "Mhp_iso_3D_table",#tableau des propriétés des matériaux en humidité
+                self.syrthesIHMCollector.Material_humidity_properties_3D_form.Mhp_aniso_3D_table : "Mhp_aniso_3D_table",#tableau des propriétés des matériaux en humidité
                 #Conjugate heat transfer
                 self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Sc_table : "Cht_Sc_table", # surface coupling
                 self.syrthesIHMCollector.Conjugate_heat_transfer_form.Cht_Vc_table : "Cht_Vc_table", # volume coupling
@@ -177,12 +189,16 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_cond_but : "Cfunc_cond_but",# bouton user C function pour la conduction
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_ray_but : "Cfunc_ray_but",# bouton user C function pour le rayonnement
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_hmt_but : "Cfunc_hmt_but",# bouton user C function pour la humidité
+                self.syrthesIHMCollector.User_C_function_form.Cfunc_fluid1d_but : "Cfunc_fluid1d_but",# bouton user C function pour cfd1d
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_other_but : "Cfunc_other_but", # bouton other user C functions
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_lne : "Cfunc_lne",
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_cond_lne : "Cfunc_cond_lne",
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_ray_lne : "Cfunc_ray_lne",
                 self.syrthesIHMCollector.User_C_function_form.Cfunc_hmt_lne : "Cfunc_hmt_lne",
-                self.syrthesIHMCollector.User_C_function_form.Cfunc_other_lne : "Cfunc_other_lne",                    
+                self.syrthesIHMCollector.User_C_function_form.Cfunc_fluid1d_lne : "Cfunc_fluid1d_lne",
+                self.syrthesIHMCollector.User_C_function_form.Cfunc_other_lne : "Cfunc_other_lne",
+                self.syrthesIHMCollector.User_C_function_form.Cfunc_test_compile : "Cfunc_test_compile",
+
                 self.syrthesIHMCollector.Advanced_mode_form.Advanced_cmd_table : "Advanced_cmd_table", # mode avancé
                 # Output
                 self.syrthesIHMCollector.Output_2D_form.Tf_cb_2D_Op : "Tf_cb_2D_Op", 
@@ -201,11 +217,47 @@ def WhatsThis(self, parent=None):
                 self.syrthesIHMCollector.Output_3D_form.Op_Dc_3D_table : "Op_Dc_3D_table", 
                 self.syrthesIHMCollector.Output_3D_form.Op_Sb_3D_table : "Op_Sb_3D_table", 
                 self.syrthesIHMCollector.Output_3D_form.Op_Vb_3D_table : "Op_Vb_3D_table",
+                self.syrthesIHMCollector.Output_3D_form.Hf_cb_3D_Op : "Hf_cb_3D_Op",
+                self.syrthesIHMCollector.Output_3D_form.Mt_cb_3D_Op : "Mt_cb_3D_Op",
+                self.syrthesIHMCollector.Output_3D_form.F_cb_3D_Op : "F_cb_3D_Op",
+                self.syrthesIHMCollector.Output_2D_form.Hf_cb_2D_Op : "Hf_cb_2D_Op",
+                self.syrthesIHMCollector.Output_2D_form.Mt_cb_2D_Op : "Mt_cb_2D_Op",
+                self.syrthesIHMCollector.Output_2D_form.F_cb_2D_Op : "F_cb_2D_Op",
                 self.syrthesIHMCollector.Home_form.Ho_Ds_te : "Ho_Ds_te",
                 self.syrthesIHMCollector.Solar_aspect_form.Sa_chb : "Sa_chb",
                 self.syrthesIHMCollector.Solar_aspect_form.Asm_Lat_cmb : "Asm_Lat_cmb",
                 self.syrthesIHMCollector.Solar_aspect_form.Asm_Lng_cmb : "Asm_Lng_cmb",
-                self.syrthesIHMCollector.Solar_aspect_form.Csm_Db_table : "Csm_Db_table"
+                self.syrthesIHMCollector.Solar_aspect_form.Csm_Db_table : "Csm_Db_table",
+
+                #fluid1d
+                self.syrthesIHMCollector.Initial_conditions_fluid1d_form.Init_TV_table : "Init_TV_table", #tableau des temperature et vitesse initiales
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Heat_ex_table : "Heat_ex_table", #tableau de l'échange de chaleur
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Flux_cond_table : "Flux_cond_table", #tableau de la condition du flux
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Inlet_3D_table : "Bcfluid1d_Inlet_3D_table", #tableau Inlet 3D
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_1df_lne : "Bcfluid1d_1df_lne",#champ d'édition du fluide 1D des faces
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_1dfUc_lne : "Bcfluid1d_1dfUc_lne",#champ d'édition User comments du fluide 1D des faces
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Prop_fluid1d_table : "Prop_fluid1d_table", #tableau des proprietes du fluide
+                self.syrthesIHMCollector.Geometrie_fluid1d_form.Geom_fluid1d_table : "Geom_fluid1d_table", # tableau pour la geometrie pour fluid1d
+                self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Source_fluid1d_table : "Source_fluid1d_table", # tableau terme source fluid1d
+                self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Linear_head_fluid1d_table : "Linear_head_fluid1d_table", # tableau perte de charge fluid1d reguliere
+                self.syrthesIHMCollector.Volumetric_conditions_fluid1d_form.Singular_head_fluid1d_table : "Singular_head_fluid1d_table", # tableau perte de charge fluid1d singuliere
+                self.syrthesIHMCollector.Control_fluid1d_form.Cb_solid_Ts_fluid1d : "Cb_solid_Ts_fluid1d", #checkbox pour indiquer que le pas de temps FLUIDE 1D est egal au pas de temps solide
+                self.syrthesIHMCollector.Control_fluid1d_form.Le_const_Ts_fluid1d : "Le_const_Ts_fluid1d", #champ éditable du pas de temps FLUIDE 1D
+                
+                # DH (BT)
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_cl : "Bcfluid1d_Q_table_cl", #champ d'édition de la closed loop
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Q_table_th_cl : "Bcfluid1d_Q_table_th_cl", #champ d'édition de la thermal closed loop
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_table_DP : "Bcfluid1d_table_DP", #champ d'édition de la delta pressure
+                self.syrthesIHMCollector.Boundary_conditions_fluid1d_3D_form.Bcfluid1d_Coupling_table : "Bcfluid1d_Coupling_table", #champ d'édition de la faces fluides couplees
+                self.syrthesIHMCollector.Filename_form.Fn_fluid1d_but : "Fn_fluid1d_but",#bouton de saisie du fichier de fluid 1d
+                self.syrthesIHMCollector.Filename_form.Fn_fluid1d_lne : "Fn_fluid1d_lne",#champ éditable du fichier de fluid 1d
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Le_Gravity_x : "Le_Gravity_x", #Gravité X
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Le_Gravity_y : "Le_Gravity_y", #Gravité Y
+                self.syrthesIHMCollector.Physical_prop_fluid1d_form.Le_Gravity_z : "Le_Gravity_z", #Gravité Z
+                self.syrthesIHMCollector.Boundary_conditions_fluid0d_form.Heat_ex_fluid0d_table : "Heat_ex_fluid0d_table",
+                self.syrthesIHMCollector.Physical_properties_fluid0d_form.Prop_fluid0d_table : "Prop_fluid0d_table",
+                self.syrthesIHMCollector.Geometrie_fluid0d_form.Geom_fluid0d_table : "Geom_fluid0d_table", # tableau pour la geometrie pour fluid0d
+                self.syrthesIHMCollector.Volumetric_conditions_fluid0d_form.Volumetric_conditions_fluid0d_table : "Volumetric_conditions_fluid0d_table" # tableau pour la conditions volumetriques pour fluid0d
                 } 
 
     for wid in self.widget:      
