@@ -15,6 +15,7 @@ class clMyTabWidget(QtGui.QTabWidget):
         self.nbTotal = -1
         self.nbActif = -1
         self.curveIndexLinked = []
+        self.yRightEnabled = []
     
     def initView(self): # à appeler absolument lorsque la fenêtre Calculation progress est initialisée
         # sauvegarder les onglets actuels dans self.tabs        
@@ -24,11 +25,12 @@ class clMyTabWidget(QtGui.QTabWidget):
         self.nbActif = 4 # 
         for i in range(self.nbTotal):
             self.tabs.append(self.widget(i))
-            self.curveIndexLinked.append(-1)
-        self.curveIndexLinked[0] = 0
+            self.curveIndexLinked.append((-1,-1))
+            self.yRightEnabled.append(False)
+        self.curveIndexLinked[0] = 0,0
 
     def boolAwaitingData(self):
         flag = True
         for i in range(self.count()): 
-            if self.curveIndexLinked[i] >= 0 : flag = False
+            if self.curveIndexLinked[i][0] >= 0 and self.curveIndexLinked[i][1] >= 0 : flag = False
         return flag
