@@ -129,19 +129,19 @@ PART_SCOTCH=no
         else :
             makefileinFile.write("PART_SCOTCH=no\n")	    
 	    
-        if self.dicolib['specific_inc'].has_key('PATH'):
-            makefileinFile.write("INC += "+self.dicolib['specific_inc']['PATH']+"\n")
+        if self.dicospeci['specific_inc'].has_key('PATH'):
+            makefileinFile.write("INC += "+self.dicospeci['specific_inc']['PATH']+"\n")
         else :
             makefileinFile.write("INC=\n")
 	      
-        if self.dicolib['specific_lib'].has_key('PATH'):
-            makefileinFile.write("LIB += "+self.dicolib['specific_lib']['PATH']+"\n")
+        if self.dicospeci['specific_lib'].has_key('PATH'):
+            makefileinFile.write("LIB += "+self.dicospeci['specific_lib']['PATH']+"\n")
         else :
             makefileinFile.write("LIB=\n")
 
-        if self.dicolib['specific_debug'].has_key('PATH'):
+        if self.dicospeci['specific_debug'].has_key('PATH'):
             makefileinFile.write("DEBUG=yes\n")
-            makefileinFile.write("COPTIM= "+self.dicolib['specific_debug']['PATH']+"\n")
+            makefileinFile.write("COPTIM= "+self.dicospeci['specific_debug']['PATH']+"\n")
         else:
             makefileinFile.write("COPTIM= -O3\n")
 
@@ -175,8 +175,8 @@ ifeq ($(PROF),yes)
 endif
 
 """)
-        if self.dicolib['specific_option'].has_key('PATH'):
-            makefileinFile.write("CFLAG += "+self.dicolib['specific_option']['PATH']+"\n")
+        if self.dicospeci['specific_option'].has_key('PATH'):
+            makefileinFile.write("CFLAG += "+self.dicospeci['specific_option']['PATH']+"\n")
             
         makefileinFile.write("""
 
@@ -231,7 +231,7 @@ LIB_SYRTHES = $(NAMELIB)
 
         if self.dicolib['mpi']['USE'].upper()=='YES':
             makefileinFile.write("# Compiler path for mpicc\n")
-            makefileinFile.write("CC="+self.dicolib['mpi']['PATH']+"/bin/mpicc\n"+"\n")
+            makefileinFile.write("CC="+self.dicolib['mpi']['PATH']+"/bin/"+self.wrapperc+"\n"+"\n")
         else:
             makefileinFile.write("CC="+self.comp+"\n")
 
@@ -274,12 +274,12 @@ LIB_SYRTHES = $(NAMELIB)
 # kernel library directory, MAkefile.in path, material library
 DIRLIB_KERNEL =$(BUILD_SYRTHES)/lib
 MAKEINC = $(DIR_SYRTHES)
-INC_SYRTHES_BIBMAT = -I$(DIR_SYRTHES)/src/syrthes-kernel/bib_material_syrthes
+INC_SYRTHES_LIBMAT = -I$(DIR_SYRTHES)/src/syrthes-kernel/lib_material_syrthes
 
 # for choosing your own SYRTHES libraries :
 #DIRLIB_KERNEL =/home/foo/mylib
 #MAKEINC = /home/foo/mymake
-#INC_SYRTHES_BIBMAT = -I/home/foo/mymateriallib
+#INC_SYRTHES_LIBMAT = -I/home/foo/mymateriallib
 
 #.....................................................................
 
@@ -328,12 +328,12 @@ endif
         # ---------------------------
         if  self.dicolib['metis'].has_key('PATH'):
             
-            makefileinFile.write("LIBMETIS=$(DIR_METIS)/lib/libmetis.a\n")
+            makefileinFile.write("LIBMETIS=-L $(DIR_METIS)/lib -lmetis\n")
             makefileinFile.write("INC_METIS=-I$(DIR_METIS)/include\n")
 
         if  self.dicolib['scotch'].has_key('PATH'):
             
-            makefileinFile.write("LIBSCOTCH=$(DIR_SCOTCH)/lib/libscotch.a $(DIR_SCOTCH)/lib/libscotcherr.a\n")
+            makefileinFile.write("LIBSCOTCH=-L $(DIR_SCOTCH)/lib -lscotch -L $(DIR_SCOTCH)/lib -lscotcherr\n")
             makefileinFile.write("INC_SCOTCH=-I$(DIR_SCOTCH)/include\n")
 
         makefileinFile.close()
@@ -397,19 +397,19 @@ PART_SCOTCH=no
         else :
             makefileinFile.write("PART_SCOTCH=no\n")	    
       
-        if self.dicolib['specific_inc'].has_key('PATH'):
-              makefileinFile.write("INC += -I"+self.dicolib['specific_inc']['PATH']+"\n")
+        if self.dicospeci['specific_inc'].has_key('PATH'):
+              makefileinFile.write("INC += -I"+self.dicospeci['specific_inc']['PATH']+"\n")
         else :
               makefileinFile.write("INC=\n")
 	      
-        if self.dicolib['specific_lib'].has_key('PATH'):
-              makefileinFile.write("LIB += -L"+self.dicolib['specific_lib']['PATH']+"\n")
+        if self.dicospeci['specific_lib'].has_key('PATH'):
+              makefileinFile.write("LIB += -L"+self.dicospeci['specific_lib']['PATH']+"\n")
         else :
               makefileinFile.write("LIB=\n")
 
-        if self.dicolib['specific_debug'].has_key('PATH'):
+        if self.dicospeci['specific_debug'].has_key('PATH'):
             makefileinFile.write("DEBUG=yes\n")
-            makefileinFile.write("COPTIM= "+self.dicolib['specific_debug']['PATH']+"\n")
+            makefileinFile.write("COPTIM= "+self.dicospeci['specific_debug']['PATH']+"\n")
         else:
             makefileinFile.write("COPTIM= -O3\n")
 
@@ -443,8 +443,8 @@ endif
 
 
 """)
-        if self.dicolib['specific_option'].has_key('PATH'):
-            makefileinFile.write("CFLAG += "+self.dicolib['specific_option']['PATH']+"\n")
+        if self.dicospeci['specific_option'].has_key('PATH'):
+            makefileinFile.write("CFLAG += "+self.dicospeci['specific_option']['PATH']+"\n")
             
         makefileinFile.write("""
 
@@ -492,7 +492,7 @@ LIB_SYRTHES = $(NAMELIB)
 
         if self.dicolib['mpi']['USE'].upper()=='YES':
             makefileinFile.write("# Compiler path for mpicc\n")
-            makefileinFile.write("CC="+self.dicolib['mpi']['PATH']+"/bin/mpicc\n"+"\n")
+            makefileinFile.write("CC="+self.dicolib['mpi']['PATH']+"/bin/"+self.wrapperc+"\n"+"\n")
         else:
             makefileinFile.write("CC="+self.comp+"\n")
             
@@ -523,12 +523,12 @@ LIB_SYRTHES = $(NAMELIB)
 # kernel library directory, MAkefile.in path, material library
 DIRLIB_KERNEL =$(BUILD_SYRTHES)/lib
 MAKEINC = $(DIR_SYRTHES)
-INC_SYRTHES_BIBMAT    = -I$(BUILD_SYRTHES)/include
+INC_SYRTHES_LIBMAT    = -I$(BUILD_SYRTHES)/include
 
 # for choosing your own SYRTHES libraries :
 #DIRLIB_KERNEL =/home/foo/mylib
 #MAKEINC = /home/foo/mymake
-#INC_SYRTHES_BIBMAT = -I/home/foo/mymateriallib
+#INC_SYRTHES_LIBMAT = -I/home/foo/mymateriallib
 
 
 # kernel library directory
@@ -540,8 +540,8 @@ MAKEINC = $(DIR_SYRTHES)/include
 # example :  MAKEINC = /home/myhome/w/myinclude
 
 # Name of the material propreties directory
-INC_SYRTHES_BIBMAT    = -I$(BUILD_SYRTHES)/bib_material_syrthes
-# for choosing your own library : INC_SYRTHES_BIBMAT    = -I/home/myhome/w/mybib_material
+INC_SYRTHES_LIBMAT    = -I$(BUILD_SYRTHES)/lib_material_syrthes
+# for choosing your own library : INC_SYRTHES_LIBMAT    = -I/home/myhome/w/mylib_material
 #.....................................................................
 
 INC_SYRTHES= -I$(BUILD_SYRTHES)/include
