@@ -163,8 +163,8 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
 	print "-------------------------------------------"
 
         # Parallele compilation with make -jN
-        if self.dicolib['specific_makej'].has_key('PATH'):
-            self.makeopt=self.dicolib['specific_makej']['PATH']
+        if self.dicospeci['specific_makej'].has_key('PATH'):
+            self.makeopt=self.dicospeci['specific_makej']['PATH']
             print " "
 	    print "-------------------------------------------"
 	    print "-- Parallele compilation with make"+self.makeopt
@@ -290,7 +290,7 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
            print ""
 	   print "---------------------------------------------------------"
 	   print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
-           print "Warning : installation of some composants failed"
+           print bellecouleur.ROUGE+"Warning : installation of some composants failed"+bellecouleur.NORMAL
 	   print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
  	   print "Check log files for more information...."
            print "" 
@@ -307,6 +307,7 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
     # This methode create 3 attributs
     #     self.arch = architecture name (Linux_x86_64, ...)
     #     self.compC = compiler namePath : gcc ou /home/..../gcc
+    #     self.wrapperc = compiler namePath : mpicc 
     #     self.dicolib = dictionnay of lib installing and using options
     #                  = {'med' : {'USE'='YES', 'INSTALL'='YES'   },
     #                     'hdf' : {'USE'='YES', 'INSTALL'='NO'(Default), PATH='/../syrthes4.0.0-6/extern-libraries/opt/hdf5-1.6.7/arch/Linux_x86_64'},
@@ -319,7 +320,8 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
         #
 	print "Reading setup file"
         self.dicolib = {}
-
+        self.dicospeci = {} 
+         
         self.libraries = []
 	# Graphical user Interface
 	self.listGui = ['gui']
@@ -332,9 +334,12 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
 	# Lib SYRTHES sequential, tool,user functions, parallele, preprocessor, post, syrthescfd
         self.listSYR = ['syrthesconvert','syrthesensight','syrthesmed', 'syrthesppfunc', 'syrthespp', 'syrthespost', 'syrthesseq', 'syrthesmpi', 'syrthescfd']
 
-        list_lib = self.listGui + self.listDef + self.listLib + self.listSat + self.listSYR
+        list_lib = self.listGui + self.listLib + self.listSat + self.listSYR
         for ele in list_lib:
             self.dicolib[ele] = {}
+        list_lib = self.listDef    
+        for ele in list_lib:    
+            self.dicospeci[ele] = {}
         #
         try:
             setupFile = file('setup.ini', mode='r')
@@ -348,6 +353,7 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
         #
         self.comp = 'gcc'
         self.compcx = 'g++'
+        self.wrapperc = 'mpicc'
         
         lines = setupFile.readlines()
         for line in lines:
@@ -360,14 +366,14 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
 
                 listopt = line[0].split("=")
                 list = line[0].split()
-	        list2 = line[0].split(None,1)
+                list2 = line[0].split(None,1)
 
                 # options specific case: there may be several on line
                 if listopt[0] in ['specific_inc', 'specific_lib', 'specific_debug', 'specific_option', 'specific_makej'] :
                     # Specifique INCLUDE for C compiler in file "setup" 
                     # rajouter une cle dicolib avec Use = YESn INSTALL=NO, PATH=list(1)
-                    self.dicolib[listopt[0]]['PATH'] = listopt[1]
-                    self.dicolib[listopt[0]]['USE'] = 'YES'
+                    self.dicospeci[listopt[0]]['PATH'] = listopt[1]
+                    self.dicospeci[listopt[0]]['USE'] = 'YES'
 		    
 		    # Screen out Begin 
 		    print "     Specific          : %s    %s  %s                  "     %(bellecouleur.VERT,listopt[1],bellecouleur.NORMAL)
@@ -420,6 +426,19 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
                     #-------------------------------------------------------------------------------
  		    # Screen out End
 		    
+		# C++ compiler in file "setup"            
+		elif list[0]=='wrapperC' :
+                    if len(list)!=1:
+                        name = list[1]
+		    else:
+                        name = 'mpicc'
+		    self.wrapperc = name
+		    
+		    # Screen out Begin                         
+		    print "     C wrapper         : %s   %s  %s                   "     %(bellecouleur.VERT,self.comp,bellecouleur.NORMAL)
+                    #-------------------------------------------------------------------------------
+ 		    # Screen out End
+		    
 		# Extern Lib in file "setup"
                 # find keys in file
 		else :
@@ -496,6 +515,10 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
         os.chdir(srcPath+nameLib+'/src')
 
         shutil.copy('Make.inc/Makefile.inc.x86-64_pc_linux2','Makefile.inc')
+        
+        # Pour scotch6   
+        #modif=file("./Makefile.inc","r").read().replace("LDFLAGS		= -lz -lm -lrt","LDFLAGS		= -lz -lm -lrt -lpthread")
+        #file("./Makefile.inc","w").write(modif)
 
         if os.path.exists(optPath) == False:
             os.mkdir(optPath, 0755)
@@ -536,7 +559,7 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
     def installMPI(self):
         #
         #
-        nameLib, buildPath, optPath, srcPath = self.unzipLib('mpi-1.4')
+        nameLib, buildPath, optPath, srcPath = self.unzipLib('mpi')
 	self.printResume('mpi')
 	
 	print "     "
@@ -1044,9 +1067,9 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
         setupFile.write('#--------------------------------------------------------\n')
         setupFile.write('# Architecture Name\n')
         setupFile.write('#--------------------------------------------------------\n')
-        setupFile.write('#nom_arch  Linux     <- for specific architecture\n')
-        setupFile.write('#nom_arch            <- leave empty for automatic default\n')
-        setupFile.write('#                       value (based on uname)\n')
+        setupFile.write('#nom_arch  Linux_x86_64    <- for specific architecture\n')	
+        setupFile.write('#nom_arch                  <- leave empty for automatic default\n')
+        setupFile.write('#                             value (based on uname)\n')
         setupFile.write('nom_arch '+self.arch+'\n#\n')
 	setupFile.write('#\n')
 
@@ -1060,6 +1083,11 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
         setupFile.write('#                                  automatic default\n')		
         setupFile.write('compC'+'   '+self.comp+"\n")
 	setupFile.write('#\n')     	
+	setupFile.write('#wrapperC  mpicc                 <- for specific C wrapper without path\n')
+	setupFile.write('#                                   (only needed for MPI installation)\n')
+	setupFile.write('#                                   leave mpicc for automatic default\n')
+        setupFile.write('wrapperC'+'  '+self.wrapperc+"\n")
+	setupFile.write('#\n')     	
         setupFile.write('# Specific options for compiler  \n')  
         setupFile.write('# specific_inc= specific_inc= -I /myinclude/inc -I /myinclude2/inc\n')
         setupFile.write('# specific_lib= -L /mylib/lib1 -L /mylib/lib2 \n')	
@@ -1069,10 +1097,10 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
 		        
         liblist=['specific_inc','specific_lib','specific_debug','specific_option', 'specific_makej']
 	for lib in liblist:
-        	if  self.dicolib[lib].has_key('PATH'):	
-           	  setupFile.write(lib+'  '+self.dicolib[lib]['PATH']+"\n")                 
-      	        else:
-           	  setupFile.write('# \n')	                     
+		if  self.dicospeci[lib].has_key('PATH'):	
+		  setupFile.write(lib+'  '+self.dicospeci[lib]['PATH']+"\n")                 
+		else:
+		  setupFile.write('# \n')			     
 	      
         setupFile.write('#\n')
 	setupFile.write('#\n')
@@ -1205,9 +1233,9 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
             for name in files :
                  shutil.copy(self.installPath+'/syrthes-kernel/include/'+name,self.destPath+self.arch+'/include' )
 	    
-            files = os.listdir(self.installPath+'/syrthes-kernel/bib_material_syrthes/') 
+            files = os.listdir(self.installPath+'/syrthes-kernel/lib_material_syrthes/') 
             for name in files : 
-                 shutil.copy(self.installPath+'/syrthes-kernel/bib_material_syrthes/'+name,self.destPath+self.arch+'/include' )
+                 shutil.copy(self.installPath+'/syrthes-kernel/lib_material_syrthes/'+name,self.destPath+self.arch+'/include' )
 
 
 
@@ -1248,10 +1276,12 @@ class Setup(Setupmakefilein, Setupsyrthesprofile):
 #        shutil.copy(self.installPath+'/doc/*.pdf', self.destPath+self.arch+'/share/syrthes/doc')
         shutil.copy(self.installPath+'/Makefile2.in'                  , self.destPath+self.arch+'/share/syrthes/Makefile.in')
         shutil.copytree(self.installPath+'/tests'                     , self.destPath+self.arch+'/share/syrthes/tests')
+#
+        shutil.copy(self.installPath+'/data/Makefile_mylibmat'        , self.destPath+self.arch+'/share/syrthes')
+        shutil.copytree(self.installPath+'/syrthes-kernel/mylibmat_src' , self.destPath+self.arch+'/share/syrthes/mylibmat_src')
+        shutil.copy(self.installPath+'/data/syrthes4_create_mylibmat'     , self.destPath+self.arch+'/bin')
+        shutil.copy(self.installPath+'/syrthes-gui/src/22x22/syr_hmt_material.txt'     , self.destPath+self.arch+'/include')
         pass
-
-
-
 	
     #----------------------------------------------------------------------------	
     # Function to find and unzip librairie
