@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -59,6 +59,7 @@ MPI_Status status;
 extern struct Performances perfo;
 extern struct Affichages affich;
 extern FILE *fdata;
+extern char nomcplcfdg[CHLONG];
 
 static char ch[CHLONG],motcle[CHLONG],repc[CHLONG],formule[CHLONG];
 static double dlist[100];
@@ -71,7 +72,7 @@ int nbCFD=0;
 extern struct Cfd cfd;
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE                                                |
   |======================================================================|
@@ -108,7 +109,7 @@ _sort_names(int  n, char **names, int *a)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE                                                |
   |======================================================================|
@@ -138,7 +139,7 @@ static void _add_name(const char *motcle, int n_couplings,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE                                                |
   |======================================================================|
@@ -293,7 +294,7 @@ static void _add_coupling_names(struct Cfd  *cfd)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE                                                |
   |======================================================================|
@@ -552,7 +553,7 @@ void cfd_init_couplage(struct SDparall sdparall, int ndim, struct Cfd *cfd)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE, I. RUPP                                       |
   |======================================================================|
@@ -743,6 +744,11 @@ void cfd_surf_init(struct Maillage   maillnodes,
 
   } /* End of loop on cfd couplings */
 
+
+  /* ecriture du maillage solide couple a la cfd */
+  ecrire_geom_cplcfd(nomcplcfdg,maillnodes,maillnodeus,*scoupf,*cfd);
+
+
   /* Impressions */
   /* ----------- */
 
@@ -771,7 +777,7 @@ void cfd_surf_init(struct Maillage   maillnodes,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE, I. RUPP                                       |
   |======================================================================|
@@ -849,7 +855,7 @@ void cfd_trans_surf(struct Maillage maillnodes,struct MaillageCL maillnodeus,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE, I. RUPP                                       |
   |======================================================================|
@@ -1068,7 +1074,7 @@ void cfd_vol_init(struct Maillage maillnodes,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                  COPYRIGHT EDF 2009-2010 |
+  | SYRTHES 4.3                                  COPYRIGHT EDF 2009-2010 |
   |======================================================================|
   | AUTEURS  : J. BONELLE, I. RUPP                                       |
   |======================================================================|
@@ -1141,7 +1147,7 @@ void cfd_trans_vol(struct Maillage maillnodes,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2010 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2010 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1164,7 +1170,7 @@ void cfd_fin(struct Cfd *cfd)
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : J. BONELLE        P                                       |
   |======================================================================|
