@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -35,7 +35,7 @@
 # include <math.h>
 
 #include "syr_usertype.h"
-#include "syr_hmt_bibmat.h"
+#include "syr_hmt_libmat.h"
 #include "syr_bd.h"
 #include "syr_hmt_bd.h"
 #include "syr_option.h"
@@ -59,7 +59,7 @@ extern FILE  *fresu;
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -78,7 +78,7 @@ void hmt_coeffequa(int numvar,int numterm,struct Maillage maillnodes,
   double xkrl,xkl,xpiv,xpi,betap,dhp,dht;
   double toto1,toto2,toto3,toto4,toto5;
   FILE *ftoto=NULL;
-  /* les fonctions sont definies dans bibmat.h */
+  /* les fonctions sont definies dans libmat.h */
  
 /*      double *toto,*titi,*tutu; */
 /*       toto=(double*)malloc(maillnodes.nelem*sizeof(double)); */
@@ -318,7 +318,11 @@ void hmt_coeffequa(int numvar,int numterm,struct Maillage maillnodes,
 	  alphat=fmat_falpha[nmat](constphyhmt,constmateriaux[nmat],pve[i],psat,t);
 	  eps=fphyhmt_feps(constphyhmt,constmateriaux[nmat],tauv);
 	  
-	  coeff[i]= alphat + eps/(constphyhmt.Rv*t);
+	  if (constmateriaux[nmat].eps0 < 1e-16)
+	    /* chris : en v4 pour les metaux je veux artificiellement conserver une matrice de masse non nulle pour pv */
+	    coeff[i]=1.;
+	  else 
+	    coeff[i]= alphat + eps/(constphyhmt.Rv*t);
 
 	}
 
@@ -439,7 +443,11 @@ void hmt_coeffequa(int numvar,int numterm,struct Maillage maillnodes,
 	  tauv=fmat_ftauv[nmat](constphyhmt,constmateriaux[nmat],pve[i],psat,t);
 	  eps=fphyhmt_feps(constphyhmt,constmateriaux[nmat],tauv);
 
-	  coeff[i]=  eps / (constphyhmt.Ras*t);
+	  if (constmateriaux[nmat].eps0 < 1e-16)
+	    /* chris : en v4 pour les metaux je veux artificiellement conserver une matrice de masse non nulle pour pt */
+	    coeff[i]=  1. ;
+	  else
+	    coeff[i]=  eps / (constphyhmt.Ras*t);
 	}
       break;
 
