@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -60,7 +60,7 @@ static int ilist[100];
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -80,7 +80,7 @@ void decode_clim_alloue(struct MaillageBord *maillnodebord)
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -253,11 +253,11 @@ void decode_clim_cond(struct MaillageBord *maillnodebord)
   
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
-  | Cqlcul cond ou hmt :                                                 |
+  | Calcul cond ou hmt :                                                 |
   | Typage des faces de bord pour la temperature :                       |
   |   RC,ray inf,couplees fluide, couplees ray, perio                    |
   |======================================================================| */
@@ -322,7 +322,8 @@ void decode_clim_all(struct MaillageBord *maillnodebord)
 		      printf("des faces avec resistance de contact est incorrecte\n");
 		      printf("                         elle doit avoir la forme suivante :\n");
 		      printf("                         liste_ref_1  -1  liste_ref_2\n");
-		      printf("                         exemple : CLIM_T  RES_CONTACT 23.   2 34 12 -1 5 32\n");
+		      if (nbVar==1) printf("                         exemple : CLIM  RES_CONTACT 23.   2 34 12 -1 5 32\n");
+		      else          printf("                         exemple : CLIM  RES_CONTACT  g_t g_pv (g_pt)  2 34 12 -1 5 32\n");
 		      printf("                         --> verifier le fichier fichier de donnees\n");
 		    }
 		  else if (SYRTHES_LANG == EN)
@@ -331,7 +332,9 @@ void decode_clim_all(struct MaillageBord *maillnodebord)
 		      printf("of patches with contact resistance is wrong\n");
 		      printf("                         it must have the fllowing form :\n");
 		      printf("                         ref_list_1  -1  ref_list_2\n");
-		      printf("                         example : CLIM_T  RES_CONTACT 23.  2 34 12 -1 5 32\n");
+		       if (nbVar==1) printf("                         example : CLIM  RES_CONTACT 23.  2 34 12 -1 5 32\n");
+		      else           printf("                         example : CLIM  RES_CONTACT  g_t g_pv (g_pt)  2 34 12 -1 5 32\n");
+
 		      printf("                         --> Please, check the data file\n");
 		    }
 		  syrthes_exit(1);
@@ -466,7 +469,7 @@ void decode_clim_all(struct MaillageBord *maillnodebord)
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -554,7 +557,7 @@ void lire_limite_cond(struct Clim *flux,struct Clim *diric,struct Clim *echang,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -646,7 +649,7 @@ void lire_limite_all(struct Contact *rescon,struct Clim *rayinf,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -686,7 +689,7 @@ void lire_flux(struct Clim *flux,struct MaillageCL maillnodeus,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -732,7 +735,7 @@ void lire_flux(struct Clim *flux,struct MaillageCL maillnodeus,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -773,11 +776,11 @@ void lire_echange(struct Clim *echang,struct MaillageCL maillnodeus,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
-  |        Lecture                                                       |
+  |        Lecture les RC en cond ou en hmt                              |
   |======================================================================| */
 void lire_rescon(struct Contact *rescon,struct MaillageCL maillnodeus,
 		   char *ch,int id)
@@ -828,7 +831,7 @@ void lire_rescon(struct Contact *rescon,struct MaillageCL maillnodeus,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -875,7 +878,7 @@ void lire_rayinf(struct Clim *rayinf,struct MaillageCL maillnodeus,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -978,7 +981,7 @@ void xmaill(struct Maillage maillnodes,struct MaillageBord maillnodebord,
 
       
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
    | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1125,7 +1128,7 @@ void cree_liste_clim_cond(struct Maillage maillnodes,struct MaillageBord maillno
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
    | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
