@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -50,7 +50,7 @@ extern int nbVar;
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -481,10 +481,10 @@ void lire_syrthes(struct Maillage *maillnodes,struct MaillageBord *maillnodebord
 /* 			   sdparall->tcommunrc[i+2],sdparall->tcommunrc[i+3],sdparall->nfoisrc[j+1]); */
 		}
 
-	      if (SYRTHES_LANG == FR)
-		printf("ON LIT LA FIN %d\n", nb-nv*2);
-	      else if (SYRTHES_LANG == EN)
-		printf("END being read %d\n", nb-nv*2);
+	      /* if (SYRTHES_LANG == FR) */
+	      /* 	printf("ON LIT LA FIN %d\n", nb-nv*2); */
+	      /* else if (SYRTHES_LANG == EN) */
+	      /* 	printf("END being read %d\n", nb-nv*2); */
 
 	      for (i=0;i<nb-nv*2;i++) 
 		{
@@ -535,11 +535,11 @@ void lire_syrthes(struct Maillage *maillnodes,struct MaillageBord *maillnodebord
 	  
 	  for (sdparall->adrcommunperio[0]=0,i=1;i<sdparall->nparts;i++)  
 	    sdparall->adrcommunperio[i]=sdparall->adrcommunperio[i-1]+sdparall->nbcommunperio[i-1]*2;
-	  if (SYRTHES_LANG == FR)
-	    printf("nombre de noeuds commun avec les autres part\n");
-	  else if (SYRTHES_LANG == EN)
-	    printf("number of nodes common with other parts\n");
-	  for (i=0;i<sdparall->nparts;i++) printf(" %d",sdparall->nbcommunperio[i]);printf("\n");
+	  /* if (SYRTHES_LANG == FR) */
+	  /*   printf("nombre de noeuds commun avec les autres part\n"); */
+	  /* else if (SYRTHES_LANG == EN) */
+	  /*   printf("number of nodes common with other parts\n"); */
+	  /* for (i=0;i<sdparall->nparts;i++) printf(" %d",sdparall->nbcommunperio[i]);printf("\n"); */
 	  
 	  /* C$ RUBRIQUE = PARALLELISME  - PERIODICITE */
 	  fgets(ch,90,fgeom);
@@ -577,12 +577,12 @@ void lire_syrthes(struct Maillage *maillnodes,struct MaillageBord *maillnodebord
 
 	      for (i=0;i<nb*2;i++) sdparall->tcommunperio[i]--;
 	      
-	      if (SYRTHES_LANG == FR)
-		printf("Couples de noeuds periodiques : part %d\n",sdparall->rang);
-	      else if (SYRTHES_LANG == EN)
-		printf("Couples of periodic nodes : part %d\n",sdparall->rang);
-	      for (i=j=0;i<nb*2;i+=2,j++) 
-		printf("(%d,%d / %d)",sdparall->tcommunperio[i],sdparall->tcommunperio[i+1],sdparall->nfoisperio[j]);printf("\n");
+	      /* if (SYRTHES_LANG == FR) */
+	      /* 	printf("Couples de noeuds periodiques : part %d\n",sdparall->rang); */
+	      /* else if (SYRTHES_LANG == EN) */
+	      /* 	printf("Couples of periodic nodes : part %d\n",sdparall->rang); */
+	      /* for (i=j=0;i<nb*2;i+=2,j++)  */
+	      /* 	printf("(%d,%d / %d)",sdparall->tcommunperio[i],sdparall->tcommunperio[i+1],sdparall->nfoisperio[j]);printf("\n"); */
 	    }
 
 	} /* fin de la periodicite */
@@ -805,7 +805,7 @@ void lire_syrthes(struct Maillage *maillnodes,struct MaillageBord *maillnodebord
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -929,7 +929,7 @@ void lire_suite(struct Maillage maillnodes,
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2010 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2010 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
