@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -53,7 +53,7 @@ extern FILE *fdata;
 extern  double c2,tsoleil;
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -92,7 +92,7 @@ void lire_donnees_ray(struct Maillage maillnodes,struct Maillage *maillnodray,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -224,7 +224,7 @@ void lire_ray_mc(struct GestionFichiers *gestionfichiers,struct PropInfini *prop
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -675,7 +675,7 @@ void lire_divers_ray(struct Maillage maillnodray,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -730,9 +730,8 @@ void lire_limite_ray(struct Maillage maillnodray,struct ProphyRay phyray,
 			  }
 		    }
 		}
-
-
-	      if (!strcmp(motcle,"INDICE_DE_REFRACTION_PAR_BANDE")) 
+	      
+	      else if (!strcmp(motcle,"INDICE_DE_REFRACTION_PAR_BANDE")) 
 		{
 		  rep_ndbl(2,dlist,&ii,ch+id);
 		  rep_listint(ilist,&nb,ch+id+ii);
@@ -746,8 +745,14 @@ void lire_limite_ray(struct Maillage maillnodray,struct ProphyRay phyray,
 			  if (maillnodray.nrefe[i]==nr) vitre->refrac[(int)(*dlist)-1][i]=*(dlist+1);
 		    }
 		}
-	      
-	      else if (!strcmp(motcle,"TEMPERATURE_IMPOSEE")) 
+	    }
+	  
+	  else if (!strcmp(motcle,"CLIM_RAYT")) 
+	    {
+	      extr_motcle(motcle,ch+i2+1,&i3,&i4);
+	      id=i2+1+i4+1;
+
+	      if (!strcmp(motcle,"TEMPERATURE_IMPOSEE")) 
 		{
 		  rep_ndbl(1,&val,&ii,ch+id);
 		  rep_listint(ilist,&nb,ch+id+ii);
@@ -781,7 +786,7 @@ void lire_limite_ray(struct Maillage maillnodray,struct ProphyRay phyray,
 		}
 
 
-	    }
+	    } /* fin CLIM_RAYT */
 	}
     }
 
