@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -54,7 +54,7 @@ static double dlist[100];
 static int ilist[100];
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -93,7 +93,7 @@ int existe_perio()
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -160,6 +160,27 @@ void lire_perio(struct Cperio *perio,
 					       it,zero,zero,zero,zero,zero,zero,zero);
 		      free(np1); free(np2);
 		    }
+		  else
+		    {
+		      printf("     dans le message  motcle=%s\n",motcle);
+		      
+		      if (sdparall.nparts==1 ||sdparall.rang==0){
+			if (SYRTHES_LANG == FR)
+			  {
+			    printf("\n !!! ERREUR lors de la lecture des conditions aux limites\n");
+			    printf("            Le mot-cle suivant n'est pas reconnu :\n");
+			    printf("            --> CLIM=  PERIODICITE_2D %s\n",motcle);
+			  }  
+			else if (SYRTHES_LANG == EN)
+			  {
+			    printf("\n !!! ERROR while reading boundary conditions\n");
+			    printf("            The following keyword is not recognized :\n");
+			    printf("            --> CLIM=  PERIODICITE_2D %s\n",motcle);
+			  }  
+		      }
+		      syrthes_exit(1);
+		    }   
+
 		}
 	      else if (!strcmp(motcle,"PERIODICITE_3D")) 
 		{
@@ -200,28 +221,26 @@ void lire_perio(struct Cperio *perio,
 					       it,zero,zero,zero,zero,zero,zero,zero);
 		      free(np1); free(np2);
 		    }
+		  else
+		    {
+		      if (sdparall.nparts==1 ||sdparall.rang==0){
+			if (SYRTHES_LANG == FR)
+			  {
+			    printf("\n !!! ERREUR lors de la lecture des conditions aux limites\n");
+			    printf("            Le mot-cle suivant n'est pas reconnu :\n");
+			    printf("            --> CLIM=  PERIODICITE_3D %s\n",motcle);
+			  }  
+			else if (SYRTHES_LANG == EN)
+			  {
+			    printf("\n !!! ERROR while reading boundary conditions\n");
+			    printf("            The following keyword is not recognized :\n");
+			    printf("            --> CLIM=  PERIODICITE_3D %s\n",motcle);
+			  }  
+		      }
+		      syrthes_exit(1);
+		    }   
 		}
-	      else
-		{
-		  
-		  if (sdparall.nparts==1 ||sdparall.rang==0){
-		    if (SYRTHES_LANG == FR)
-		      {
-			printf(" !!! ERREUR lors de la lecture des conditions aux limites\n");
-			printf("            Le mot-cle suivant n'est pas reconnu :\n");
-			printf("            --> CLIM=  PERIODICITE_ %s\n",motcle);
-		      }  
-		    else if (SYRTHES_LANG == EN)
-		      {
-			printf(" !!! ERROR during the boundary condition reading\n");
-			printf("            The following keyword is not recognized :\n");
-			printf("            --> CLIM=  PERIODICITE_ %s\n",motcle);
-		      }  
-		  }
-		  syrthes_exit(1);
-		}   
 	    }
-	  
 	}
     }
 
@@ -237,10 +256,11 @@ void lire_perio(struct Cperio *perio,
       printf("       - total number of periodic nodes  : %d\n",perio->npoin);
       printf("       - total number of periodic elements : %d\n",perio->nelem);
     }
+  fflush(stdout);
 } 
   
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -390,7 +410,7 @@ void cree_liste_noeuds_periorc(struct MaillageBord maillnodebord,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -509,6 +529,7 @@ void cree_paires_noeuds_perio(struct Maillage maillnodes,
       printf("         for the couple of nodes    : %d %d\n",perio->nump[iminmin],
                                                                    perio->numpc[iminmin]);
     }
+  fflush(stdout);
 
   if (!perio->npoin)
     {
@@ -546,7 +567,7 @@ void cree_paires_noeuds_perio(struct Maillage maillnodes,
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
@@ -569,7 +590,7 @@ void rotation2d(double px,double py,double teta,
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : C. PENIGUEL, I. RUPP                                      |
   |======================================================================|
