@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -32,9 +32,9 @@
 
 /*===========================================================================
  * Main API functions for coupling between Syrthes and Code_Saturne
- * AUTHORS  : J. Bonelle, Y Fournier                                      
+ * AUTHORS  : J. Bonelle, Y Fournier
  *
- * Library: Syrthes                                   Copyright EDF 2008-2010
+ * Library: Syrthes                                   Copyright EDF 2008-2014
  *===========================================================================*/
 
 #if defined(_SYRTHES_CFD_)
@@ -48,6 +48,7 @@
 #include <math.h>
 #include <float.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
 #if defined(_SYRTHES_MPI_)
@@ -120,7 +121,7 @@ typedef struct _syr_cfd_interpolation_t {
 
   int             n_coupled_elts;      /* Number of coupled elements */
 
-  ple_lnum_t     *coupled_elt_list;    /* List of coupled elements (1 to n) */
+  int            *coupled_elt_list;    /* List of coupled elements (1 to n) */
   float          *coeffs;              /* Interpolation coefficients */
 
   const int     **elt_vertices;        /* Pointer to SYRTHES coonectivity */
@@ -148,6 +149,9 @@ struct _syr_cfd_coupling_t {
   syr_cfd_interpolation_t  *face_ip;    /* Interpolation for faces */
 
   int              conservativity;  /* Conservativity forcing flag */
+  int              allow_nearest;   /* Allow nearest flag */
+  double           tolerance[2];    /* Tolerance for location
+                                       0: absolute, 1: relative*/
 
 };
 
@@ -165,6 +169,8 @@ static MPI_Comm _syr_coupling_loc_comm = MPI_COMM_NULL;
 
 static ple_coupling_mpi_set_t *_syr_coupling_mpi_app_world = NULL;
 
+static int _syr_coupling_app_sync_flags = 0;
+
 #endif
 
 /*===========================================================================
@@ -306,10 +312,12 @@ _exchange_sync(syr_cfd_coupling_t  *coupling,
  *
  * parameters:
  *  coupling <-- Associated coupling object
+ *  error    <-- 1 if location error has occured previously, 0 otherwise
  *----------------------------------------------------------------------------*/
 
 static void
-_coupling_start(syr_cfd_coupling_t  *coupling)
+_coupling_start(syr_cfd_coupling_t  *coupling,
+                int                  error)
 {
   char  op_name_send[32 + 1];
   char  op_name_recv[32 + 1];
@@ -318,7 +326,13 @@ _coupling_start(syr_cfd_coupling_t  *coupling)
 
   memset(op_name_send, 0, 32);
 
-  strcpy(op_name_send, "coupling:start");
+  if (error) {
+    strcpy(op_name_send, "coupling:error:location");
+    _syr_coupling_app_sync_flags
+      = _syr_coupling_app_sync_flags | PLE_COUPLING_STOP;
+  }
+  else
+    strcpy(op_name_send, "coupling:start");
 
   _exchange_sync(coupling, op_name_send, op_name_recv);
 
@@ -326,10 +340,22 @@ _coupling_start(syr_cfd_coupling_t  *coupling)
 
   if (strcmp(op_name_recv, "coupling:start"))  {
 
-    ple_error(__FILE__, __LINE__, 0,
-              _("Message \"%s\" indicates an error or unexpected.\n"
-                "--> abort."),
-              op_name_recv);
+    if (strcmp(op_name_recv, "coupling:error:location") == 0)  {
+
+      _syr_coupling_app_sync_flags
+        = _syr_coupling_app_sync_flags | PLE_COUPLING_STOP;
+
+      ple_printf(_("Message \"%s\" indicates a mesh matching error.\n"
+                   "--> abort."),
+                 op_name_recv);
+      fflush(stdout);
+
+    }
+    else
+      ple_error(__FILE__, __LINE__, 0,
+                _("Message \"%s\" indicates an error or unexpected.\n"
+                  "--> abort."),
+                op_name_recv);
 
   }
 }
@@ -353,6 +379,8 @@ _init_mpi_comm(syr_cfd_coupling_t *cfd_coupling,
 {
 
   int  mpi_flag = 0;
+  int  scheme_min = 2;
+  int  scheme_max = 2;
 
   char  volume_flag = ' ';
   char  boundary_flag = ' ';
@@ -381,14 +409,14 @@ _init_mpi_comm(syr_cfd_coupling_t *cfd_coupling,
     int distant_range[2] = {-1, -1};
 
     ple_coupling_mpi_intracomm_create(MPI_COMM_WORLD,
-				      _syr_coupling_loc_comm,
+                                      _syr_coupling_loc_comm,
                                       cfd_coupling->root_dist_rank,
                                       &(cfd_coupling->comm),
                                       local_range,
                                       distant_range);
 
-    ple_printf(_("CFD coupling: local_ranks   = [%d..%d]\n"
-                 "              distant ranks = [%d..%d]\n"),
+    ple_printf(_("CFD coupling: local_ranks =                 [%d..%d]\n"
+                 "              distant ranks =               [%d..%d]\n"),
                local_range[0], local_range[1] - 1,
                distant_range[0], distant_range[1] - 1);
 
@@ -397,7 +425,6 @@ _init_mpi_comm(syr_cfd_coupling_t *cfd_coupling,
 
   }
 
-  ple_printf(_(" [ok]\n"));
   fflush(stdout);
 
   /* Exchange coupling options */
@@ -425,18 +452,62 @@ _init_mpi_comm(syr_cfd_coupling_t *cfd_coupling,
     conserv_flag = '1';
   }
 
-  /*  Only CFD code set its conservativity forcing flag.
-      To avoid an error, set the conservativity flag in op_name_send */
-  
-  sprintf(op_name_send, "coupling:type:%c%c%c",
-          boundary_flag, volume_flag, conserv_flag);
+  /* Leave id 17 open for volume conservativity flag */
 
-  /* Ancienne version pour Code_Saturne 2.1 */
-  /* cfd_coupling->conservativity = 0; */
-  /* sprintf(op_name_send, "coupling:type:%c%c", */
-  /*         boundary_flag, volume_flag); */
+  /* Exchange scheme version information, with a min and max scheme number so as to
+     allow forward/backward compatibility across some scheme changes:
+     both codes should follow the maximum common handled scheme.
+     Scheme numbers are only to be increased when additional
+     or different data are passed. Changes not breaking a given scheme (such as
+     better error handling by passing additional messages instead of aborting
+     immediately do not require increasing its number. As the first versioned scheme
+     is the current version, a blank in the scheme version character places
+     is assumed to be scheme 1. */
 
-  if (strcmp(op_name_recv, op_name_send))
+  if (op_name_recv[18] == ' ' || op_name_recv[18] == '\2')
+    scheme_min = 2;
+  else
+    scheme_min = (int)(op_name_recv[18]);
+  if (op_name_recv[19] == ' ' || op_name_recv[19] == '\2')
+    scheme_max = 2;
+  else
+    scheme_max = (int)(op_name_recv[19]);
+
+  /* Tolerance information is exchanged also */
+
+  if (op_name_recv[20] == '0')
+    cfd_coupling->allow_nearest = 0;
+  else
+    cfd_coupling->allow_nearest = 1;
+
+  cfd_coupling->tolerance[0] = 0.;  /* default */
+  cfd_coupling->tolerance[1] = 0.1; /* default */
+  if (op_name_recv[21] == '(') {
+    int i = 0, j = 22;
+    char tolerance_str[32] = "";
+    while (j < 33) {
+     if (op_name_recv[j] == ')')
+        break;
+      else
+        tolerance_str[i++] = op_name_recv[j++];
+    }
+    tolerance_str[i++] = '\0';
+    cfd_coupling->tolerance[1] = atof(tolerance_str);
+    if (cfd_coupling->tolerance[1] <= 0)
+      cfd_coupling->tolerance[1] = 0.1;
+  }
+  ple_printf(_("              communication scheme version: %d\n"
+               "              conservativity flag:          %d\n"
+               "              allow nonmatching:            %d\n"
+               "              tolerance:                    %-6.2g %-6.2g\n"),
+             scheme_max, cfd_coupling->conservativity,
+             cfd_coupling->allow_nearest,
+             cfd_coupling->tolerance[0], cfd_coupling->tolerance[1]);
+  fflush(stdout);
+
+  /* Check compatibility */
+
+  if (strncmp(op_name_recv, op_name_send, 16))
     ple_error
       (__FILE__, __LINE__, 0,
        _("========================================================\n"
@@ -560,7 +631,7 @@ _shape_functions_tetra(syr_cfd_interpolation_t   *ip,
 {
   /* Local variables */
 
-  ple_lnum_t i, j;
+  int i, j;
 
   const ple_locator_t *l = ip->locator;
   const ple_lnum_t n_dist = ple_locator_get_n_dist_points(l);
@@ -573,7 +644,7 @@ _shape_functions_tetra(syr_cfd_interpolation_t   *ip,
 
   for (i = 0; i < n_dist; i++) {
 
-    ple_lnum_t e_id = ip->coupled_elt_list[dist_loc[i] - 1];
+    int    e_id = ip->coupled_elt_list[dist_loc[i] - 1];
     double t_coords[4][3];
 
     double vol6;
@@ -655,7 +726,7 @@ _shape_functions_tria_3d(syr_cfd_interpolation_t   *ip,
 {
   /* Local variables */
 
-  ple_lnum_t i;
+  int   i;
 
   const ple_locator_t *l = ip->locator;
   const ple_lnum_t n_dist = ple_locator_get_n_dist_points(l);
@@ -669,13 +740,13 @@ _shape_functions_tria_3d(syr_cfd_interpolation_t   *ip,
 
   for (i = 0; i < n_dist; i++) {
 
-    ple_lnum_t j, coord_idx_0, coord_idx_1, coord_idx_2;
+    int    j, coord_idx_0, coord_idx_1, coord_idx_2;
 
     double t[3], u[3], v[3], w[3], vect_tmp[3];
     double uu, vv, uv, ut, vt, ww, det;
     double isop_0, isop_1;
 
-    ple_lnum_t e_id = ip->coupled_elt_list[dist_loc[i] - 1];
+    int    e_id = ip->coupled_elt_list[dist_loc[i] - 1];
 
     coord_idx_0 = elt_vertices[0][e_id];
     coord_idx_1 = elt_vertices[1][e_id];
@@ -751,7 +822,7 @@ _shape_functions_tria_2d(syr_cfd_interpolation_t  *ip,
 {
   /* Local variables */
 
-  ple_lnum_t i;
+  int   i;
 
   const ple_locator_t *l = ip->locator;
   const ple_lnum_t n_dist = ple_locator_get_n_dist_points(l);
@@ -765,13 +836,13 @@ _shape_functions_tria_2d(syr_cfd_interpolation_t  *ip,
 
   for (i = 0; i < n_dist; i++) {
 
-    ple_lnum_t j, coord_idx_0, coord_idx_1, coord_idx_2;
+    int    j, coord_idx_0, coord_idx_1, coord_idx_2;
 
     double t[3], u[3], v[3];
     double uu, vv, uv, ut, vt, det;
     double isop_0, isop_1;
 
-    ple_lnum_t e_id = ip->coupled_elt_list[dist_loc[i] - 1];
+    int    e_id = ip->coupled_elt_list[dist_loc[i] - 1];
 
     coord_idx_0 = elt_vertices[0][e_id];
     coord_idx_1 = elt_vertices[1][e_id];
@@ -829,7 +900,7 @@ _shape_functions_edge_2d(syr_cfd_interpolation_t   *ip,
 {
   /* Local variables */
 
-  ple_lnum_t i;
+  int   i;
 
   const ple_locator_t *l = ip->locator;
   const ple_lnum_t n_dist = ple_locator_get_n_dist_points(l);
@@ -842,12 +913,12 @@ _shape_functions_edge_2d(syr_cfd_interpolation_t   *ip,
 
   for (i = 0; i < n_dist; i++) {
 
-    ple_lnum_t  j, coord_idx_0, coord_idx_1;
+    int    j, coord_idx_0, coord_idx_1;
 
     double u[2], v[2];
     double uv, len, isop_0;
 
-    ple_lnum_t e_id = ip->coupled_elt_list[dist_loc[i] - 1];
+    int    e_id = ip->coupled_elt_list[dist_loc[i] - 1];
 
     coord_idx_0 = elt_vertices[0][e_id];
     coord_idx_1 = elt_vertices[1][e_id];
@@ -909,7 +980,7 @@ _build_syr_cfd_mesh(int             dim,
 {
   /* Local variables */
 
-  ple_lnum_t i, j;
+  int  i, j;
 
   int  max_vertex_num = 0;   /* Highest vertex number for elements in list*/
 
@@ -918,8 +989,8 @@ _build_syr_cfd_mesh(int             dim,
 
   syr_cfd_element_t elt_type = SYR_CFD_N_ELEMENT_TYPES;
 
-  ple_lnum_t *_elt_vertices = NULL;
-  ple_coord_t *_vertex_coords = NULL;
+  int  *_elt_vertices = NULL;
+  double  *_vertex_coords = NULL;
 
   int nve = elt_dim + 1;
 
@@ -947,7 +1018,7 @@ _build_syr_cfd_mesh(int             dim,
     }
   }
 
-  PLE_MALLOC(_vertex_coords, max_vertex_num*dim, ple_coord_t);
+  PLE_MALLOC(_vertex_coords, max_vertex_num*dim, double);
 
   for (i = 0; i < max_vertex_num; i++) {
     for (j = 0; j < dim; j++)
@@ -956,7 +1027,7 @@ _build_syr_cfd_mesh(int             dim,
 
   /* Build connectivity array */
 
-  PLE_MALLOC(_elt_vertices, n_coupled_elts*nve, ple_lnum_t);
+  PLE_MALLOC(_elt_vertices, n_coupled_elts*nve, int);
 
   for (i = 0; i < n_coupled_elts; i++) {
     int elt_id = coupled_elts[i];
@@ -1032,6 +1103,56 @@ _interpolation_destroy(syr_cfd_interpolation_t **ip)
   PLE_FREE(*ip);
 }
 
+/*----------------------------------------------------------------------------
+ * Check if coupling location is complete
+ *
+ * arguments:
+ *   coupl          <-> coupling helper structure
+ *   ip             <-> coupling interpolation helper structure
+
+ * returns:
+ *   1 if location is incomplete, 0 if it is complete
+ *----------------------------------------------------------------------------*/
+
+static int
+_is_location_incomplete(syr_cfd_coupling_t       *coupl,
+                        syr_cfd_interpolation_t  *ip)
+{
+  /* Local variables */
+
+  int  location_incomplete = 0;
+  int  flag_glob = 0;
+
+  char  op_name_send[32 + 1];
+  char  op_name_recv[32 + 1];
+
+  if (ple_locator_get_n_exterior(ip->locator) > 0)
+    location_incomplete = 1;
+
+#if defined(_SYRTHES_MPI_)
+  {
+    int n_ranks = 1;
+    MPI_Comm_size(_syr_coupling_loc_comm, &n_ranks);
+    if (n_ranks > 1) {
+      int flag_loc = location_incomplete;
+      MPI_Allreduce(&flag_loc, &location_incomplete, 1, MPI_INT, MPI_MAX,
+                    _syr_coupling_loc_comm);
+    }
+  }
+#endif
+
+  if (location_incomplete > 0)
+    strcpy(op_name_send, "coupling:location:incomplete");
+  else
+    strcpy(op_name_send, "coupling:location:ok");
+
+  _exchange_sync(coupl, op_name_send, op_name_recv);
+  if (!strcmp(op_name_recv, "coupling:location:incomplete"))
+    location_incomplete = 1;
+
+  return location_incomplete;
+}
+
 /*----------------------------------------------------------------------------
  * Initialize interpolation structure.
  *
@@ -1062,7 +1183,7 @@ _interpolation_init(syr_cfd_coupling_t       *coupl,
 {
   /* Local variables */
 
-  ple_lnum_t i;
+  int   i;
 
   int  flag_glob = 0;
   int  flag_loc = 0;
@@ -1074,10 +1195,6 @@ _interpolation_init(syr_cfd_coupling_t       *coupl,
   ple_coord_t  *elt_centers = NULL;
   float *dist_to_cfd = NULL;
 
-  ple_mesh_elements_closest_t  *locate_on_closest = NULL;
-
-  const double  tolerance = 0.1;
-
   /* Check if cells are coupled, and return if this is not the case */
 
   if (n_coupled_elts > 0) {
@@ -1087,11 +1204,11 @@ _interpolation_init(syr_cfd_coupling_t       *coupl,
 
 #if defined(_SYRTHES_MPI_)
   {
-   int  n_ranks = 1;
-   MPI_Comm_size(_syr_coupling_loc_comm, &n_ranks);
-   if (n_ranks > 1)
-     MPI_Allreduce(&flag_loc, &flag_glob, 1, MPI_INT, MPI_MAX,
-                   _syr_coupling_loc_comm);
+    int  n_ranks = 1;
+    MPI_Comm_size(_syr_coupling_loc_comm, &n_ranks);
+    if (n_ranks > 1)
+      MPI_Allreduce(&flag_loc, &flag_glob, 1, MPI_INT, MPI_MAX,
+                    _syr_coupling_loc_comm);
   }
 #endif
 
@@ -1100,19 +1217,14 @@ _interpolation_init(syr_cfd_coupling_t       *coupl,
 
   /* Initialization */
 
-  if (elt_dim == dim - 1)
-    locate_on_closest = syr_cfd_point_location_closest;
-
 #if defined(_SYRTHES_MPI_)
-  ip->locator = ple_locator_create(tolerance,
-                                   coupl->comm,
+  ip->locator = ple_locator_create(coupl->comm,
                                    coupl->n_dist_ranks,
                                    coupl->root_dist_rank);
 #else
-  ip->locator = ple_locator_create(tolerance);
+  ip->locator = ple_locator_create();
 #endif
 
-
   if (dim == 3) {
     if (elt_dim == 2)
       elt_type = SYR_CFD_TRIA;
@@ -1153,21 +1265,53 @@ _interpolation_init(syr_cfd_coupling_t       *coupl,
 
   /* Initialize location of correspondants */
 
-  if (locate_on_closest)
+  if (elt_dim == dim - 1)
     PLE_MALLOC(dist_to_cfd, n_coupled_elts, float);
 
   ple_locator_set_mesh(ip->locator,
                        elts,
+                       NULL,
+                       coupl->tolerance[0],
+                       coupl->tolerance[1],
                        dim,
                        n_coupled_elts,
                        NULL,
+                       NULL,
                        elt_centers,
                        dist_to_cfd,
                        syr_cfd_point_location_extents,
-                       syr_cfd_point_location_contain,
-                       locate_on_closest);
+                       syr_cfd_point_location_contain);
 
-  if (locate_on_closest) {
+  flag_loc = _is_location_incomplete(coupl, ip);
+
+  if (coupl->allow_nearest) {
+
+    float tolerance = coupl->tolerance[1];
+
+    while (flag_loc > 0) {
+
+      tolerance *= 4;
+
+      ple_locator_extend_search(ip->locator,
+                                elts,
+                                NULL,
+                                0,
+                                tolerance,
+                                n_coupled_elts,
+                                NULL,
+                                NULL,
+                                elt_centers,
+                                dist_to_cfd,
+                                syr_cfd_point_location_extents,
+                                syr_cfd_point_location_contain);
+
+      flag_loc = _is_location_incomplete(coupl, ip);
+
+    }
+
+  }
+
+  if (elt_dim == dim - 1) {
     ple_locator_exchange_point_var(ip->locator,
                                    NULL,
                                    dist_to_cfd,
@@ -1180,23 +1324,34 @@ _interpolation_init(syr_cfd_coupling_t       *coupl,
 
   /* Check that all element centers are located */
 
-  assert(ple_locator_get_n_exterior(ip->locator) == 0);
+  if (ple_locator_get_n_exterior(ip->locator) == 0)  {
 
-  PLE_FREE(elt_centers);
+    PLE_FREE(elt_centers);
 
-  /* Build interpolation coefficients */
+    /* Build interpolation coefficients */
+
+    if (dim == 3) {
+      if (elt_dim == 2)
+        _shape_functions_tria_3d(ip, elt_vertices, vertex_coords);
+      else if (elt_dim == 3)
+        _shape_functions_tetra(ip, elt_vertices, vertex_coords);
+    }
+    else if (dim == 2) {
+      if (elt_dim == 1)
+        _shape_functions_edge_2d(ip, elt_vertices, vertex_coords);
+      if (elt_dim == 2)
+        _shape_functions_tria_2d(ip, elt_vertices, vertex_coords);
+    }
+
+    flag_loc = 0;
 
-  if (dim == 3) {
-    if (elt_dim == 2)
-      _shape_functions_tria_3d(ip, elt_vertices, vertex_coords);
-    else if (elt_dim == 3)
-      _shape_functions_tetra(ip, elt_vertices, vertex_coords);
   }
-  else if (dim == 2) {
-    if (elt_dim == 1)
-      _shape_functions_edge_2d(ip, elt_vertices, vertex_coords);
-    if (elt_dim == 2)
-      _shape_functions_tria_2d(ip, elt_vertices, vertex_coords);
+  else {
+
+    PLE_FREE(elt_centers);
+
+    flag_loc = 1;
+
   }
 
   /* Interpolation meshes are not required anymore */
@@ -1210,7 +1365,7 @@ _interpolation_init(syr_cfd_coupling_t       *coupl,
 
   /* Exchange synchronization message */
 
-  _coupling_start(coupl);
+  _coupling_start(coupl, flag_loc);
 }
 
 /*----------------------------------------------------------------------------
@@ -1225,12 +1380,12 @@ static void
 _send_nodal_var(syr_cfd_interpolation_t  *ip,
                 const double             *var)
 {
-  ple_lnum_t i;
+  int i;
 
   int e_id;
   int v0, v1, v2, v3;
 
-  ple_lnum_t n_dist = ple_locator_get_n_dist_points(ip->locator);
+  int     n_dist = ple_locator_get_n_dist_points(ip->locator);
   double *var_send = NULL;
 
   const ple_lnum_t *dist_loc = ple_locator_get_dist_locations(ip->locator);
@@ -1310,7 +1465,7 @@ static void
 _send_elt_var(syr_cfd_interpolation_t  *ip,
               const double             *var)
 {
-  ple_lnum_t i;
+  int i;
 
   ple_lnum_t n_dist = ple_locator_get_n_dist_points(ip->locator);
   double *var_send = NULL;
@@ -1471,7 +1626,7 @@ syr_cfd_coupling_finalize(void)
 syr_cfd_coupling_t *
 syr_cfd_coupling_create(int                       dim,
                         const char               *app_name,
-			syr_cfd_coupling_type_t   type)
+                        syr_cfd_coupling_type_t   type)
 {
   /* local variables */
   int  len;
@@ -1509,11 +1664,18 @@ syr_cfd_coupling_create(int                       dim,
     coupling->cell_ip = _interpolation_create();
   }
   else if (type == SYR_NO_COUPLING)
-    ple_printf(_("\n  Warning: No coupling type defined\n")); 
+    ple_printf(_("\n  Warning: No coupling type defined\n"));
   else
     ple_error(__FILE__, __LINE__, 0,
               _("\n  Unknown coupling type.\n  --> abort."));
 
+  /* Define some defaults */
+
+  coupling->conservativity = 0;
+  coupling->allow_nearest = 1;
+  coupling->tolerance[0] = 0.;
+  coupling->tolerance[1] = 0.1;
+
   return coupling;
 }
 
@@ -1699,7 +1861,7 @@ syr_cfd_coupling_sync_apps(int      flags,
     app_status
       = ple_coupling_mpi_set_get_status(_syr_coupling_mpi_app_world);
 
-    sync_flags = app_status[app_id] | flags;
+    sync_flags = app_status[app_id] | (flags | _syr_coupling_app_sync_flags);
 
     if (current_ts_id >= *max_ts_id)
       sync_flags = sync_flags | PLE_COUPLING_STOP;
@@ -1836,7 +1998,7 @@ syr_cfd_coupling_supervise(syr_cfd_coupling_t  *coupling,
 
   /* Prepare command message */
 
-  if (*is_end == 1)
+  if (*is_end == 1 || _syr_coupling_app_sync_flags | PLE_COUPLING_STOP)
     strcpy(op_name_send, "cmd:stop");
 
   else
@@ -1898,7 +2060,7 @@ syr_cfd_coupling_cell_vars(syr_cfd_coupling_t  *coupling,
                            double              *t_cell,
                            double              *h_cell)
 {
-  ple_lnum_t i;
+  int i;
 
   syr_cfd_interpolation_t  *ip = coupling->cell_ip;
   double *recv_buf = NULL;
@@ -1954,7 +2116,7 @@ syr_cfd_coupling_face_vars(syr_cfd_coupling_t  *coupling,
                            double              *t_face,
                            double              *h_face)
 {
-  ple_lnum_t i;
+  int i;
 
   syr_cfd_interpolation_t  *ip = coupling->face_ip;
   double *recv_buf = NULL;
