@@ -125,9 +125,9 @@ enum {X, Y, Z};
 
 typedef struct {
 
-  ple_lnum_t  octant_id[8];   /* Ids of sub-octants in octree array */
-  ple_lnum_t  idx[9];         /* Start index of point list for each octant */
-  ple_lnum_t  n_points;       /* Number of points in octree */
+  int   octant_id[8];         /* Ids of sub-octants in octree array */
+  int   idx[9];               /* Start index of point list for each octant */
+  int   n_points;             /* Number of points in octree */
 
 } _octant_t;
 
@@ -139,7 +139,7 @@ typedef struct {
 
   double       extents[6];    /* Associated extents */
 
-  ple_lnum_t  *point_ids;     /* Id's of points sorted by octree
+  int         *point_ids;     /* Id's of points sorted by octree
                                  (size: n_points + 1) */
   _octant_t   *nodes;         /* Array of octree nodes
                                  (size: n_nodes_max) */
@@ -152,9 +152,9 @@ typedef struct {
 
 typedef struct {
 
-  ple_lnum_t  quadrant_id[4]; /* Id of sub-quadrants in quadtree array */
-  ple_lnum_t  idx[5];         /* Start index of point list for each quadrant */
-  ple_lnum_t  n_points;       /* Number of points in quadtree */
+  int   quadrant_id[4];       /* Id of sub-quadrants in quadtree array */
+  int   idx[5];               /* Start index of point list for each quadrant */
+  int   n_points;             /* Number of points in quadtree */
 
 } _quadrant_t;
 
@@ -166,7 +166,7 @@ typedef struct {
 
   double        extents[4];   /* Associated extents */
 
-  ple_lnum_t   *point_ids;    /* Id's of points sorted by quadtree
+  int          *point_ids;    /* Id's of points sorted by quadtree
                                  (size: n_points + 1) */
   _quadrant_t  *nodes;        /* Array of quadtree nodes
                                  (size: n_nodes_max) */
@@ -179,7 +179,7 @@ typedef struct {
 
 static double      _epsilon_denom = 1.e-28; /* Minimum denominator */
 
-static ple_lnum_t  _octree_threshold = 4; /* Number of points in octree node
+static int         _octree_threshold = 4; /* Number of points in octree node
                                              under which the node is final */
 
 /*============================================================================
@@ -293,14 +293,14 @@ _within_extents(int                dim,
  *----------------------------------------------------------------------------*/
 
 inline static void
-_update_elt_extents(int                 dim,
-                    ple_lnum_t          vertex_id,
-                    const ple_coord_t   vertex_coords[],
-                    double              elt_extents[],
-                    int                *elt_initialized)
+_update_elt_extents(int            dim,
+                    int            vertex_id,
+                    const double   vertex_coords[],
+                    double         elt_extents[],
+                    int           *elt_initialized)
 {
-  ple_lnum_t  i;
-  ple_lnum_t coord_idx = vertex_id;
+  int i;
+  int coord_idx = vertex_id;
 
   if (*elt_initialized == 0) {
     for (i = 0; i < dim; i++) {
@@ -377,13 +377,13 @@ _elt_extents_finalize(int               dim,
 
 static void
 _point_extents(const int            dim,
-               const ple_lnum_t     n_points,
-               const ple_lnum_t     point_index[],
+               const int            n_points,
+               const int            point_index[],
                const ple_coord_t    point_coords[],
                double               extents[])
 {
   int i;
-  ple_lnum_t j, coord_idx;
+  int j, coord_idx;
 
   /* initialize extents in case mesh is empty or dim < 3 */
   for (i = 0; i < dim; i++) {
@@ -437,13 +437,13 @@ _point_extents(const int            dim,
 static void
 _build_octree_leaves(const double        extents[],
                      const ple_coord_t   point_coords[],
-                     ple_lnum_t         *point_ids_tmp,
+                     int                *point_ids_tmp,
                      _octree_t          *octree,
-                     ple_lnum_t          point_range[2])
+                     int                 point_range[2])
 {
-  ple_lnum_t i, j, k, _n_nodes, _n_points, tmp_size;
+  int i, j, k, _n_nodes, _n_points, tmp_size;
 
-  ple_lnum_t count[8], idx[9], octant_id[8];
+  int count[8], idx[9], octant_id[8];
   double mid[3], sub_extents[6];
   _octant_t  *_node;
 
@@ -595,11 +595,11 @@ _build_octree_leaves(const double        extents[],
  *----------------------------------------------------------------------------*/
 
 static _octree_t
-_build_octree(ple_lnum_t         n_points,
+_build_octree(int                n_points,
               const ple_coord_t  point_coords[])
 {
   size_t i;
-  ple_lnum_t point_range[2];
+  int point_range[2];
   _octree_t _octree;
 
   int *point_ids_tmp = NULL;
@@ -623,7 +623,7 @@ _build_octree(ple_lnum_t         n_points,
                    point_coords,
                    _octree.extents);
 
-    PLE_MALLOC(_octree.point_ids, _octree.n_points, ple_lnum_t);
+    PLE_MALLOC(_octree.point_ids, _octree.n_points, int);
 
     for (i = 0; i < _octree.n_points; i++)
       _octree.point_ids[i] = i;
@@ -685,8 +685,8 @@ _query_octree_node(const double        extents[],
                    const _octree_t    *octree,
                    const double        node_extents[],
                    int                 node_id,
-                   ple_lnum_t         *loc_point_ids,
-                   ple_lnum_t         *n_loc_points)
+                   int                *loc_point_ids,
+                   int                *n_loc_points)
 {
   _octant_t *node;
   int i, j, k;
@@ -751,7 +751,7 @@ _query_octree_node(const double        extents[],
 
           for (k = node->idx[i]; k < node->idx[i+1]; k++) {
 
-            ple_lnum_t point_id = octree->point_ids[k];
+            int point_id = octree->point_ids[k];
 
             if (_within_extents(dim, point_coords + point_id*dim, extents)) {
               loc_point_ids[*n_loc_points] = point_id;
@@ -785,8 +785,8 @@ static void
 _query_octree(const double        extents[],
               const ple_coord_t   point_coords[],
               const _octree_t    *octree,
-              ple_lnum_t         *n_loc_points,
-              ple_lnum_t          loc_point_ids[])
+              int                *n_loc_points,
+              int                 loc_point_ids[])
 {
   *n_loc_points = 0;
 
@@ -817,13 +817,13 @@ _query_octree(const double        extents[],
 static void
 _build_quadtree_leaves(const double        extents[],
                        const ple_coord_t   point_coords[],
-                       ple_lnum_t         *point_ids_tmp,
+                       int                *point_ids_tmp,
                        _quadtree_t        *quadtree,
-                       ple_lnum_t          point_range[2])
+                       int                 point_range[2])
 {
-  ple_lnum_t i, j, k, _n_nodes, _n_points, tmp_size;
+  int i, j, k, _n_nodes, _n_points, tmp_size;
 
-  ple_lnum_t count[4], idx[5], quadrant_id[4];
+  int count[4], idx[5], quadrant_id[4];
   double mid[2], sub_extents[4];
   _quadrant_t  *_node;
 
@@ -963,11 +963,11 @@ _build_quadtree_leaves(const double        extents[],
  *----------------------------------------------------------------------------*/
 
 static _quadtree_t
-_build_quadtree(ple_lnum_t         n_points,
+_build_quadtree(int                n_points,
                 const ple_coord_t  point_coords[])
 {
   size_t i;
-  ple_lnum_t point_range[2];
+  int point_range[2];
   _quadtree_t _quadtree;
 
   int *point_ids_tmp = NULL;
@@ -991,7 +991,7 @@ _build_quadtree(ple_lnum_t         n_points,
                    point_coords,
                    _quadtree.extents);
 
-    PLE_MALLOC(_quadtree.point_ids, _quadtree.n_points, ple_lnum_t);
+    PLE_MALLOC(_quadtree.point_ids, _quadtree.n_points, int);
 
     for (i = 0; i < _quadtree.n_points; i++)
       _quadtree.point_ids[i] = i;
@@ -1053,8 +1053,8 @@ _query_quadtree_node(const double        extents[],
                      const _quadtree_t  *quadtree,
                      const double        node_extents[],
                      int                 node_id,
-                     ple_lnum_t         *loc_point_ids,
-                     ple_lnum_t         *n_loc_points)
+                     int                *loc_point_ids,
+                     int                *n_loc_points)
 {
   _quadrant_t *node;
   int i, j, k;
@@ -1110,7 +1110,7 @@ _query_quadtree_node(const double        extents[],
 
           for (k = node->idx[i]; k < node->idx[i+1]; k++) {
 
-            ple_lnum_t point_id = quadtree->point_ids[k];
+            int point_id = quadtree->point_ids[k];
 
             if (_within_extents(2, point_coords + point_id*2, extents)) {
               loc_point_ids[*n_loc_points] = point_id;
@@ -1144,8 +1144,8 @@ static void
 _query_quadtree(const double        extents[],
                 const ple_coord_t   point_coords[],
                 const _quadtree_t  *quadtree,
-                ple_lnum_t         *n_loc_points,
-                ple_lnum_t          loc_point_ids[])
+                int                *n_loc_points,
+                int                 loc_point_ids[])
 {
   *n_loc_points = 0;
 
@@ -1181,17 +1181,17 @@ _query_quadtree(const double        extents[],
  *----------------------------------------------------------------------------*/
 
 static void
-_locate_on_edge_2d(ple_lnum_t           elt_num,
-                   const ple_lnum_t     element_vertex_num[],
-                   const ple_coord_t    vertex_coords[],
-                   const ple_coord_t    point_coords[],
-                   ple_lnum_t           n_points_in_extents,
-                   const ple_lnum_t     points_in_extents[],
-                   double               tolerance,
-                   ple_lnum_t           location[],
-                   float                distance[])
+_locate_on_edge_2d(int                elt_num,
+                   const int          element_vertex_num[],
+                   const double       vertex_coords[],
+                   const ple_coord_t  point_coords[],
+                   int                n_points_in_extents,
+                   const int          points_in_extents[],
+                   double             tolerance,
+                   ple_lnum_t         location[],
+                   float              distance[])
 {
-  ple_lnum_t  i, j, k, coord_idx_0, coord_idx_1;
+  int  i, j, k, coord_idx_0, coord_idx_1;
 
   double u[2], v[2];
   double uv, len2, isop_0;
@@ -1283,17 +1283,17 @@ _locate_on_edge_2d(ple_lnum_t           elt_num,
  *----------------------------------------------------------------------------*/
 
 static void
-_locate_on_triangle_3d(ple_lnum_t           elt_num,
-                       const ple_lnum_t     element_vertex_num[],
-                       const ple_coord_t    vertex_coords[],
-                       const ple_coord_t    point_coords[],
-                       ple_lnum_t           n_points_in_extents,
-                       const ple_lnum_t     points_in_extents[],
-                       const double         tolerance,
-                       ple_lnum_t           location[],
-                       float                distance[])
+_locate_on_triangle_3d(int                elt_num,
+                       const int          element_vertex_num[],
+                       const double       vertex_coords[],
+                       const ple_coord_t  point_coords[],
+                       int                n_points_in_extents,
+                       const int          points_in_extents[],
+                       const double       tolerance,
+                       ple_lnum_t         location[],
+                       float              distance[])
 {
-  ple_lnum_t  i, j, k, coord_idx_0, coord_idx_1, coord_idx_2;
+  int  i, j, k, coord_idx_0, coord_idx_1, coord_idx_2;
 
   double t[3], u[3], v[3], w[3], vect_tmp[3];
   double uu, vv, uv, ut, vt, ww, det, tmp_max;
@@ -1420,17 +1420,17 @@ _locate_on_triangle_3d(ple_lnum_t           elt_num,
  *----------------------------------------------------------------------------*/
 
 static void
-_locate_in_triangle_2d(ple_lnum_t           elt_num,
-                       const ple_lnum_t     element_vertex_num[],
-                       const ple_coord_t    vertex_coords[],
-                       const ple_coord_t    point_coords[],
-                       ple_lnum_t           n_points_in_extents,
-                       const ple_lnum_t     points_in_extents[],
-                       double               tolerance,
-                       ple_lnum_t           location[],
-                       float                distance[])
+_locate_in_triangle_2d(int                elt_num,
+                       const int          element_vertex_num[],
+                       const double       vertex_coords[],
+                       const ple_coord_t  point_coords[],
+                       int                n_points_in_extents,
+                       const int          points_in_extents[],
+                       double             tolerance,
+                       ple_lnum_t         location[],
+                       float              distance[])
 {
-  ple_lnum_t  i, j, k, coord_idx_0, coord_idx_1, coord_idx_2;
+  int  i, j, k, coord_idx_0, coord_idx_1, coord_idx_2;
 
   double t[2], u[2], v[2], shapef[3];
   double uu, vv, uv, ut, vt, det;
@@ -1522,12 +1522,12 @@ _locate_in_triangle_2d(ple_lnum_t           elt_num,
  *----------------------------------------------------------------------------*/
 
 static void
-_locate_in_tetra(ple_lnum_t         elt_num,
-                 const ple_lnum_t   element_vertex_num[],
-                 const ple_coord_t  vertex_coords[],
+_locate_in_tetra(int                elt_num,
+                 const int          element_vertex_num[],
+                 const double       vertex_coords[],
                  const ple_coord_t  point_coords[],
-                 ple_lnum_t         n_points_in_extents,
-                 const ple_lnum_t   points_in_extents[],
+                 int                n_points_in_extents,
+                 const int          points_in_extents[],
                  double             tolerance,
                  ple_lnum_t         location[],
                  float              distance[])
@@ -1540,10 +1540,10 @@ _locate_in_tetra(ple_lnum_t         elt_num,
   double t00, t10, t20, t01, t02, t03, t11, t12, t13, t21, t22, t23;
   double v01[3], v02[3], v03[3], shapef[4];
 
-  ple_coord_t  tetra_coords[4][3];
+  double  tetra_coords[4][3];
 
   for (i = 0; i < 4; i++) {
-    ple_lnum_t coord_idx = element_vertex_num[i] -1;
+    int coord_idx = element_vertex_num[i] -1;
     for (j = 0; j < 3; j++)
       tetra_coords[i][j] = vertex_coords[(coord_idx * 3) + j];
   }
@@ -1641,14 +1641,14 @@ _mesh_locate_3d(const syr_cfd_mesh_t  *mesh,
                 double                 tolerance,
                 const ple_coord_t      point_coords[],
                 _octree_t             *octree,
-                ple_lnum_t             points_in_extents[],
+                int                    points_in_extents[],
                 ple_lnum_t             location[],
                 float                  distance[])
 {
-  ple_lnum_t  i, j;
+  int  i, j;
   double elt_extents[6];
 
-  ple_lnum_t n_points_in_extents = 0;
+  int n_points_in_extents = 0;
 
   const int stride = syr_cfd_mesh_n_vertices_element[mesh->element_type];
   const int elt_dim = stride - 1; /* true for simplexes */
@@ -1661,7 +1661,7 @@ _mesh_locate_3d(const syr_cfd_mesh_t  *mesh,
     int elt_initialized = 0;
 
     for (j = 0; j < stride; j++) {
-      ple_lnum_t vertex_id = mesh->vertex_num[i*stride + j] - 1;
+      int vertex_id = mesh->vertex_num[i*stride + j] - 1;
       _update_elt_extents(3,
                           vertex_id,
                           mesh->vertex_coords,
@@ -1703,59 +1703,6 @@ _mesh_locate_3d(const syr_cfd_mesh_t  *mesh,
   }
 }
 
-/*----------------------------------------------------------------------------
- * Find elements in a given section closest to 3d points: updates the
- * location[] and distance[] arrays associated with a set of points
- * for points that are in an element of this section, or closer to one
- * than to previously encountered elements.
- *
- * parameters:
- *   mesh              <-- pointer to mesh representation structure
- *   point_coords      <-- point coordinates
- *   n_point_ids       <-- number of points to locate
- *   point_id          <-- ids of points to locate
- *   location          <-> number of element containing or closest to each
- *                         point (size: n_points)
- *   distance          <-> distance from point to element indicated by
- *                         location[]: < 0 if unlocated, or absolute
- *                         distance to a surface element (size: n_points)
- *----------------------------------------------------------------------------*/
-
-static void
-_mesh_closest_3d(const syr_cfd_mesh_t  *mesh,
-                 const ple_coord_t      point_coords[],
-                 ple_lnum_t             n_point_ids,
-                 const ple_lnum_t       point_ids[],
-                 ple_lnum_t             location[],
-                 float                  distance[])
-{
-  ple_lnum_t  i;
-
-  const int stride = syr_cfd_mesh_n_vertices_element[mesh->element_type];
-
-  if (mesh->n_elements == 0)
-    return;
-
-  if (mesh->element_type == SYR_CFD_TETRA)
-    ple_error(__FILE__, __LINE__, 0,
-              _("Locating volume elements closest to points not handled yet"));
-
-  else if (mesh->element_type == SYR_CFD_TRIA) {
-
-    for (i = 0; i < mesh->n_elements; i++)
-      _locate_on_triangle_3d(i + 1,
-                             mesh->vertex_num + i*stride,
-                             mesh->vertex_coords,
-                             point_coords,
-                             n_point_ids,
-                             point_ids,
-                             (HUGE_VAL / 4.),
-                             location,
-                             distance);
-
-  }
-}
-
 /*----------------------------------------------------------------------------
  * Find elements in a given section containing 2d points: updates the
  * location[] and distance[] arrays associated with a set of points
@@ -1781,14 +1728,14 @@ _mesh_locate_2d(const syr_cfd_mesh_t  *mesh,
                 double                 tolerance,
                 const ple_coord_t      point_coords[],
                 _quadtree_t           *quadtree,
-                ple_lnum_t             points_in_extents[],
+                int                    points_in_extents[],
                 ple_lnum_t             location[],
                 float                  distance[])
 {
-  ple_lnum_t  i, j;
+  int  i, j;
   double elt_extents[4];
 
-  ple_lnum_t n_points_in_extents = 0;
+  int n_points_in_extents = 0;
 
   const int stride = syr_cfd_mesh_n_vertices_element[mesh->element_type];
   const int elt_dim = stride - 1; /* true for simplexes */
@@ -1803,7 +1750,7 @@ _mesh_locate_2d(const syr_cfd_mesh_t  *mesh,
     int elt_initialized = 0;
 
     for (j = 0; j < stride; j++) {
-      ple_lnum_t vertex_id = mesh->vertex_num[i*stride + j] - 1;
+      int vertex_id = mesh->vertex_num[i*stride + j] - 1;
       _update_elt_extents(2,
                           vertex_id,
                           mesh->vertex_coords,
@@ -1846,60 +1793,6 @@ _mesh_locate_2d(const syr_cfd_mesh_t  *mesh,
   } /* End of loop on elements */
 }
 
-/*----------------------------------------------------------------------------
- * Find elements in a given section closest to 3d points: updates the
- * location[] and distance[] arrays associated with a set of points
- * for points that are in an element of this section, or closer to one
- * than to previously encountered elements.
- *
- * parameters:
- *   mesh              <-- pointer to mesh representation structure
- *   point_coords      <-- point coordinates
- *   n_point_ids       <-- number of points to locate
- *   point_id          <-- ids of points to locate
- *   location          <-> number of element containing or closest to each
- *                         point (size: n_points)
- *   distance          <-> distance from point to element indicated by
- *                         location[]: < 0 if unlocated, or absolute
- *                         distance to a line element (size: n_points)
- *----------------------------------------------------------------------------*/
-
-static void
-_mesh_closest_2d(const syr_cfd_mesh_t  *mesh,
-                 const ple_coord_t      point_coords[],
-                 ple_lnum_t             n_point_ids,
-                 const ple_lnum_t       point_id[],
-                 ple_lnum_t             location[],
-                 float                  distance[])
-{
-  ple_lnum_t  i;
-
-  const int stride = syr_cfd_mesh_n_vertices_element[mesh->element_type];
-
-  /* Return immediately if nothing to do for this rank */
-
-  if (mesh->n_elements == 0 || mesh->element_type != SYR_CFD_EDGE)
-    return;
-
-  /* Main loop on elements */
-
-  for (i = 0; i < mesh->n_elements; i++) {
-
-    /* Locate on edge */
-
-    _locate_on_edge_2d(i + 1,
-                       mesh->vertex_num + i*stride,
-                       mesh->vertex_coords,
-                       point_coords,
-                       n_point_ids,
-                       point_id,
-                       -1.0,
-                       location,
-                       distance);
-
-  } /* End of loop on elements */
-}
-
 /*============================================================================
  * Public function definitions
  *============================================================================*/
@@ -1920,14 +1813,14 @@ _mesh_closest_2d(const syr_cfd_mesh_t  *mesh,
  *   the number of extents computed
  *----------------------------------------------------------------------------*/
 
-ple_lnum_t
+int
 syr_cfd_point_location_extents(const void  *mesh,
                                ple_lnum_t   n_max_extents,
                                double       tolerance,
                                double       extents[])
 {
   const syr_cfd_mesh_t  *m = mesh;
-  ple_lnum_t retval = 0;
+  int retval = 0;
 
   if (m == NULL)
     return 0;
@@ -1942,7 +1835,7 @@ syr_cfd_point_location_extents(const void  *mesh,
   else if (n_max_extents > 0 && n_max_extents < m->n_elements) {
 
     int i;
-    ple_lnum_t j, k, vertex_id;
+    int j, k, vertex_id;
     double elt_extents[6];
 
     int dim = m->dim;
@@ -1987,7 +1880,7 @@ syr_cfd_point_location_extents(const void  *mesh,
 
   else if (n_max_extents == m->n_elements) {
 
-    ple_lnum_t j, k, vertex_id;
+    int j, k, vertex_id;
 
     int dim = m->dim;
     int stride = syr_cfd_mesh_n_vertices_element[m->element_type];
@@ -2031,23 +1924,29 @@ syr_cfd_point_location_extents(const void  *mesh,
  * than to previously encountered elements.
  *
  * parameters:
- *   mesh         <-- pointer to mesh representation structure
- *   tolerance    <-- associated tolerance
- *   n_points     <-- number of points to locate
- *   point_coords <-- point coordinates
- *   location     <-> number of element containing or closest to each
- *                    point (size: n_points)
- *   distance     <-> distance from point to element indicated by
- *                    location[]: < 0 if unlocated, 0 - 1 if inside,
- *                    and > 1 if outside a volume element, or absolute
- *                    distance to a surface element (size: n_points)
+ *   mesh               <-- pointer to mesh representation structure
+ *   tolerance_base     <-- associated base tolerance (used for bounding
+ *                          box check only, not for location test)
+ *   tolerance_fraction <-- associated fraction of element bounding boxes
+ *                          added to tolerance
+ *   n_points           <-- number of points to locate
+ *   point_coords       <-- point coordinates
+ *   point_tag          <-- optional point tag (unused here)
+ *   location           <-> number of element containing or closest to each
+ *                          point (size: n_points)
+ *   distance           <-> distance from point to element indicated by
+ *                          location[]: < 0 if unlocated, 0 - 1 if inside,
+ *                          and > 1 if outside a volume element, or absolute
+ *                          distance to a surface element (size: n_points)
  *----------------------------------------------------------------------------*/
 
 void
 syr_cfd_point_location_contain(const void         *mesh,
-                               double              tolerance,
+                               float               tolerance_base,
+                               float               tolerance_fraction,
                                ple_lnum_t          n_points,
                                const ple_coord_t   point_coords[],
+                               const ple_lnum_t    point_tag[],
                                ple_lnum_t          location[],
                                float               distance[])
 {
@@ -2056,14 +1955,14 @@ syr_cfd_point_location_contain(const void         *mesh,
 
   else {
 
-    ple_lnum_t  *points_in_extents = NULL;
+    int  *points_in_extents = NULL;
 
     const syr_cfd_mesh_t  *m = mesh;
 
     /* Build point query list
        (max size: n_points, usually much less) */
 
-    PLE_MALLOC(points_in_extents, n_points, ple_lnum_t);
+    PLE_MALLOC(points_in_extents, n_points, int);
 
     /* Use octree for 3d point location */
 
@@ -2074,7 +1973,7 @@ syr_cfd_point_location_contain(const void         *mesh,
       /* Locate for all sections */
 
       _mesh_locate_3d(m,
-                      tolerance,
+                      tolerance_fraction,
                       point_coords,
                       &octree,
                       points_in_extents,
@@ -2091,7 +1990,7 @@ syr_cfd_point_location_contain(const void         *mesh,
       _quadtree_t  quadtree = _build_quadtree(n_points, point_coords);
 
       _mesh_locate_2d(m,
-                      tolerance,
+                      tolerance_fraction,
                       point_coords,
                       &quadtree,
                       points_in_extents,
@@ -2105,72 +2004,6 @@ syr_cfd_point_location_contain(const void         *mesh,
   }
 }
 
-/*----------------------------------------------------------------------------
- * Find elements in a given mesh closest to points: updates the
- * location[] and distance[] arrays associated with a set of points
- * for points that are closer to an element of this mesh than to previously
- * encountered elements.
- *
- * This function currently only handles elements of lower dimension than
- * the spatial dimension.
- *
- * parameters:
- *   mesh         <-- pointer to mesh representation structure
- *   n_points     <-- number of points to locate
- *   point_coords <-- point coordinates
- *   location     <-> number of element containing or closest to each
- *                    point (size: n_points)
- *   distance     <-> distance from point to element indicated by
- *                    location[]: < 0 if unlocated, or absolute
- *                    distance to a surface element (size: n_points)
- *----------------------------------------------------------------------------*/
-
-void
-syr_cfd_point_location_closest(const void         *mesh,
-                               ple_lnum_t          n_points,
-                               const ple_coord_t   point_coords[],
-                               ple_lnum_t          location[],
-                               float               distance[])
-{
-  if (mesh == NULL)
-    return;
-
-  else {
-
-    ple_lnum_t j;
-    ple_lnum_t  *point_ids = NULL;
-
-    const syr_cfd_mesh_t  *m = mesh;
-
-    PLE_MALLOC(point_ids, n_points, ple_lnum_t);
-    for (j = 0; j < n_points; j++)
-      point_ids[j] = j;
-
-    /* Use brute force for closest 3d point location */
-
-    if (m->dim == 3)
-      _mesh_closest_3d(m,
-                       point_coords,
-                       n_points,
-                       point_ids,
-                       location,
-                       distance);
-
-    /* Use brute force for closest 2d point location */
-
-    else if (m->dim == 2)
-      _mesh_closest_2d(m,
-                       point_coords,
-                       n_points,
-                       point_ids,
-                       location,
-                       distance);
-
-    if (point_ids != NULL)
-      PLE_FREE(point_ids);
-  }
-}
-
 /*----------------------------------------------------------------------------*/
 
 #undef _DOT_PRODUCT
