@@ -1,6 +1,6 @@
 /*-----------------------------------------------------------------------
 
-                         SYRTHES version 4.1
+                         SYRTHES version 4.3
                          -------------------
 
      This file is part of the SYRTHES Kernel, element of the
@@ -38,7 +38,7 @@
 
 # include "syr_usertype.h"
 # include "syr_bd.h"
-# include "syr_hmt_bibmat.h"
+# include "syr_hmt_libmat.h"
 # include "syr_hmt_bd.h"
 # include "syr_parall.h"
 # include "syr_tree.h"
@@ -47,8 +47,8 @@
 # include "syr_proto.h"
 # include "syr_hmt_proto.h"
 
-#ifdef _SYRTHES_CFD_
 # include "syr_cfd.h"
+#ifdef _SYRTHES_CFD_
 # include "ple_coupling.h"
 #endif
 
@@ -64,7 +64,7 @@ int lray=0; /* =1 si au moins 1 proc fait du rayt */
 int lhumid; /* =1 si les transferts couples sont actifs */
 int lmst=0;
 int ecraddfile;   /* ecriture ou non de fichiers additionnels (calque sur les sorties chrono) */
-int user_stop=0;  /* pour generer un arret prmature mais propre du code */ 
+int user_stop=0;  /* pour generer un arret premature mais propre du code */ 
 
 extern char nomresu[CHLONG],nomresuc[CHLONG];
 extern char nomresur[CHLONG],nomresucr[CHLONG];
@@ -72,14 +72,13 @@ extern char nomadd[CHLONG],nomflu[CHLONG];
 
 extern FILE  *fdata,*fadd;
 FILE *fresu,*fchro,*fresur,*fchror,*fhisto,*fflu;
+FILE *fresucplcfd,*fchrocplcfd;
 
-#ifdef _SYRTHES_CFD_
 extern struct Cfd cfd;
-#endif
 
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -232,14 +231,11 @@ void syrthes(int rang_deb,int nbproc_ray)
 
   if (syrglob_nparts==1 ||syrglob_rang==0)
     {	    
-      if (SYRTHES_LANG == FR){
-	printf("\n INITIALISATIONS POUR LA CONDUCTION\n"); 
-	printf(" =================================\n"); 
-      }
-      else if (SYRTHES_LANG == EN)  {
-	printf("\n CONDUCTION INITIALIZATIONS\n"); 
-	printf(" ==========================\n"); 
-      }
+      printf("\n"); for (i=0;i<90;i++) printf("="); 
+      if (SYRTHES_LANG == FR) {printf("\n INITIALISATIONS POUR LA CONDUCTION\n"); 
+	                         printf(" =================================\n"); }
+      else if (SYRTHES_LANG == EN)  {printf("\n CONDUCTION INITIALIZATIONS\n"); 
+                                       printf(" ==========================\n"); }
     }
 
   /*============ Allocations of arrays depending on number of variables ===============*/
@@ -262,7 +258,8 @@ void syrthes(int rang_deb,int nbproc_ray)
 
   /* Writing head of additional file */
   ecraddfile=ecrire_chrono(0,gestionfichiers,pasdetemps,maillnodes,maillnodebord,variable,
-			   maillnodray,phyray,tmpray,firay,sdparall_ray);
+			   maillnodray,phyray,tmpray,firay,sdparall_ray,
+			   humid,constphyhmt,constmateriaux,scoupf,cfd,trav,trave);
 
   /* on a calcule la frequence d'ecriture du fichier additionnel,
      mais on ecrit toujours l'enete pour l'avoir dans les initialisations */
@@ -352,17 +349,14 @@ void syrthes(int rang_deb,int nbproc_ray)
   if (lray) 
     {
  
-      if (syrglob_nparts==1 ||syrglob_rang==0)
-	{	    
-	  if (SYRTHES_LANG == FR){
-	    printf("\n INITIALISATIONS POUR LE RAYONNEMENT\n"); 
-	    printf(" ===================================\n"); 
-	  }
-	  else if (SYRTHES_LANG == EN)  {
-	    printf("\n RADIATION INITIALIZATIONS\n"); 
-	    printf(" =========================\n"); 
-	  }
-	}
+      if (syrglob_nparts==1 ||syrglob_rang==0){	   
+	printf("\n"); for (i=0;i<90;i++) printf("="); 
+	if (SYRTHES_LANG == FR)  {printf("\n INITIALISATIONS POUR LE RAYONNEMENT\n"); 
+	  printf(" ===================================\n"); }
+	else if (SYRTHES_LANG == EN) {printf("\n RADIATION INITIALIZATIONS\n"); 
+	  printf(" =========================\n"); }
+	fflush(stdout);
+      }
  
       tcpu1=cpusyrt();
 
@@ -390,14 +384,33 @@ void syrthes(int rang_deb,int nbproc_ray)
       tcpu2=cpusyrt();
       perfo.cpu_init_ray=tcpu2-tcpu1;
       
+      if (syrglob_nparts==1 ||syrglob_rang==0){	    
+	if (SYRTHES_LANG == FR)  {printf("\n ==> OK... Fin des initialisation pour le rayonnement\n"); }
+	else if (SYRTHES_LANG == EN) {printf("\n ==> OK... End of radiation initializations\n");} 
+	fflush(stdout);
+      }
 
     }
 
   /*======================== HMT Initializations ======================================*/
   /*===================================================================================*/
   if (humid.actif){
+    if (syrglob_nparts==1 ||syrglob_rang==0){	    
+      printf("\n"); for (i=0;i<90;i++) printf("="); 
+      if (SYRTHES_LANG == FR)  {printf("\n INITIALISATIONS POUR LES TRANSFERTS COUPLES\n"); 
+ 	                        printf(  " ===========================================\n"); }
+      else if (SYRTHES_LANG == EN) {printf("\n HMT INITIALIZATIONS\n"); 
+	                            printf(  " ===================\n"); }
+      fflush(stdout);
+    }
     hmt_init(maillnodes,&constphyhmt,&constmateriaux,&humid,&var_ele);
     fflush(stdout);
+
+    if (syrglob_nparts==1 ||syrglob_rang==0){	    
+      if (SYRTHES_LANG == FR)  {printf("\n ==> OK... Fin des initialisation pour les transferts couples\n"); }
+      else if (SYRTHES_LANG == EN) {printf("\n ==> OK... End of HMT initializations\n");} 
+      fflush(stdout);
+      }
   }
 
   
@@ -419,6 +432,14 @@ void syrthes(int rang_deb,int nbproc_ray)
   scouvf.exist=scouvf.existglob=0;
 
 #ifdef _SYRTHES_CFD_ 
+
+  if (syrglob_nparts==1 ||syrglob_rang==0){	    
+    if (SYRTHES_LANG == FR)  {printf("\n INITIALISATIONS DU COUPLAGE AVEC LA CFD\n"); 
+                                printf(" =======================================\n"); }
+    else if (SYRTHES_LANG == EN) {printf("\n CFD COUPLING INITIALIZATIONS\n"); 
+                                    printf(" ============================\n"); }
+    fflush(stdout);
+  }
       
   cfd_init_couplage(sdparall, maillnodeus.ndim, &cfd);
   fflush(stdout);
@@ -442,11 +463,25 @@ void syrthes(int rang_deb,int nbproc_ray)
   cfd_synchro(&pasdetemps,cfd);
   fflush(stdout);
 
+  if (syrglob_nparts==1 ||syrglob_rang==0){	    
+    if (SYRTHES_LANG == FR)  {printf("\n ==> OK... Fin des initialisation pour le couplage CFD\n"); }
+    else if (SYRTHES_LANG == EN) {printf("\n ==> OK... End of CFD coupling initializations\n");} 
+    fflush(stdout);
+  }
+
 #endif 
 
 
   /*=============================== Initial Conditions ================================*/
   /*===================================================================================*/
+  if (syrglob_nparts==1 ||syrglob_rang==0){	    
+    printf("\n"); for (i=0;i<90;i++) printf("="); 
+    if (SYRTHES_LANG == FR)  {printf("\n MISE EN PLACE DES CONDITIONS INITIALES\n"); 
+                                printf(" ======================================\n"); }
+    else if (SYRTHES_LANG == EN) {printf("\n SETTING INITIAL CONDITIONS\n"); 
+                                    printf(" ==========================\n"); }
+    fflush(stdout);
+  }
 
   /* conditions initiales programmees */
   if (!humid.actif){
@@ -508,7 +543,12 @@ void syrthes(int rang_deb,int nbproc_ray)
     if (fluxvol[ADR_T].nelem || fluxvol[ADR_PV].nelem || fluxvol[ADR_PT].nelem )
       verify_initial_cvol(maillnodes,fluxvol); 
 
-    fflush(stdout);
+    if (syrglob_nparts==1 ||syrglob_rang==0){	    
+      if (SYRTHES_LANG == FR)  {printf("\n ==> OK... Fin des conditions initiales\n"); }
+      else if (SYRTHES_LANG == EN) {printf("\n ==> OK... End of initial conditions\n");} 
+      fflush(stdout);
+    }
+
  }
 
   /*========================== End of data initializations ============================*/
@@ -660,7 +700,9 @@ void syrthes(int rang_deb,int nbproc_ray)
 
       /* Writing head of additional file (if needed) */
       ecraddfile=ecrire_chrono(0,gestionfichiers,pasdetemps,maillnodes,maillnodebord,variable,
-			       maillnodray,phyray,tmpray,firay,sdparall_ray);
+			       maillnodray,phyray,tmpray,firay,sdparall_ray,humid,constphyhmt,constmateriaux,
+			       scoupf,cfd,
+			       trav,trave);
       if(ecraddfile)  ecrire_entete(&fadd,nomadd,pasdetemps.ntsyr,pasdetemps.rdtts,pasdetemps.tempss);
       fflush(stdout);fflush(fadd);
 
@@ -746,29 +788,35 @@ void syrthes(int rang_deb,int nbproc_ray)
       
       /*=============================== Calculs des bilans ================================*/
       /*===================================================================================*/
-      /* ????????? Attention bilans sur T uniquement */
 
-      if (bilansurf.nb) bilsurf(maillnodes,maillnodeus,scoupf,flux,echang,
-				rescon,scoupr,rayinf,variable.var[variable.adr_t_m1],bilansurf,
-				pasdetemps.tempss);
+      if (bilansurf.nb) 
+	bilsurf(maillnodes,maillnodeus,scoupf,flux,echang,
+		rescon,scoupr,rayinf,hmtclimhhh,constphyhmt,
+		variable,bilansurf,pasdetemps.tempss);
       fflush(stdout);
+
       
-/*       if (bilanvol.nb)  bilvol(maillnodes,fluxvol[ADR_T],bilanvol,pasdetemps.tempss); */
-      if (bilanvol.nb)  bilvol(maillnodes,scouvf,fluxvol[ADR_T],
-			       variable.var[variable.adr_t_m1],bilanvol,pasdetemps.tempss);
+      if (bilanvol.nb) 
+	bilvol(maillnodes,scouvf,fluxvol[ADR_T],
+	       variable,bilanvol,pasdetemps.tempss,
+	       humid,var_ele,constphyhmt,constmateriaux);
+
       fflush(stdout);
+
       
       /*=============================== Ecritures chrono ==================================*/
       /*===================================================================================*/
 
       if (gestionfichiers.freq_chrono){
 	ecrit=ecrire_chrono(1,gestionfichiers,pasdetemps,maillnodes,maillnodebord,variable,
-		      maillnodray,phyray,tmpray,firay,sdparall_ray);
+			    maillnodray,phyray,tmpray,firay,sdparall_ray,humid,constphyhmt,constmateriaux,
+			    scoupf,cfd,trav,trave);
 	if (gestionfichiers.champflux && ecrit) ecrire_flux(maillnodes,variable,physol);
 	if (ecraddfile && ecrit) user_add_var_in_file(maillnodes,fluxvol,variable,physol,pasdetemps);
       }
 
-      if (histos.actif) ecrire_histo(pasdetemps,maillnodes,histos,variable);
+      if (histos.actif) ecrire_histo(pasdetemps,maillnodes,histos,variable,
+				     humid,constphyhmt,constmateriaux);
       fflush(stdout);
 
       
@@ -848,19 +896,30 @@ void syrthes(int rang_deb,int nbproc_ray)
   /*===================================================================================*/
 
   /* fichier resultat final */
-  ecrire_resu(gestionfichiers,pasdetemps,maillnodes,variable,maillnodray,phyray,tmpray,firay,sdparall_ray);
-  fclose(fresu);
-  if (lray && fresur) fclose(fresur);
+  if (gestionfichiers.suppchampfinal==0){
+    ecrire_resu(gestionfichiers,pasdetemps,maillnodes,variable,
+		maillnodray,phyray,tmpray,firay,sdparall_ray,
+		humid,constphyhmt,constmateriaux,scoupf,cfd,trav,trave);
+    fclose(fresu);
+#ifdef _SYRTHES_CFD_ 
+    fclose(fresucplcfd);
+#endif
+  }
 
+  if (lray && fresur) fclose(fresur);
+  
   if (gestionfichiers.freq_chrono>0){
     if (fchro) fclose(fchro);
     if (lray && fchror) fclose(fchror);
+#ifdef _SYRTHES_CFD_ 
+    fclose(fchrocplcfd);
+#endif
   }    
-     
+  
   if ((syrglob_nparts==1 || syrglob_rang==0) && fflu) fclose(fflu);
-
+  
   perfo.cpu_tot=cpusyrt()-perfo.cpu_deb;
-
+  
 
   /* Closing files
      ~~~~~~~~~~~~~ */
@@ -978,7 +1037,7 @@ void syrthes(int rang_deb,int nbproc_ray)
 
 }  
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -997,7 +1056,7 @@ void syrthes_initsdparall(struct SDparall *sdparall,struct SDparall_ray *sdparal
 }
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1100,7 +1159,7 @@ void syrthes_initmpi(int rang_deb,struct SDparall *sdparall)
 #endif /* End _SYRTHES_MPI_ */
 
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
@@ -1171,7 +1230,7 @@ void syrthes_initmpi_ray(int nbproc_ray,
 
 }
 /*|======================================================================|
-  | SYRTHES 4.1                                       COPYRIGHT EDF 2009 |
+  | SYRTHES 4.3                                       COPYRIGHT EDF 2009 |
   |======================================================================|
   | AUTEURS  : I. RUPP, C. PENIGUEL                                      |
   |======================================================================|
