@@ -60,7 +60,7 @@ void ecrit_var_ensight_bin  (FILE *,rp_int,rp_int,rp_int,double,char*,double *);
 
 
 /*|======================================================================|
-  | SYRTHES 4.1 - Utilitaires                         COPYRIGHT EDF 2008 |
+  | SYRTHES 4.3 - Utilitaires                         COPYRIGHT EDF 2008 |
   |======================================================================|
   | AUTEURS  : I. RUPP                                                   |
   |======================================================================|
@@ -82,7 +82,7 @@ main (argc,argv)
   double *temps,**coord,*var;
   char nomfichcase[200],nomfichgeom[200],nomfichvar[200];
   char nomutilens[200],nomutilgeom[200],nomutilresu[200];
-  char ch[200],*nomvar[90],nombase[90],nomnum[5];
+  char ch[200],*nomvar[90],nombase[90],nomnum[6];
   char *s;
   
   numarg=0;
@@ -312,7 +312,7 @@ main (argc,argv)
       printf("\n\n Conversion of results\n");
       
       for (i=0;i<90;i++) nomvar[i]=(char*)malloc(12*sizeof(char));
-      temps=(double*)malloc(10000*sizeof(double));
+      temps=(double*)malloc(100000*sizeof(double));
       discr=(rp_int*)malloc(1000*sizeof(rp_int));
       
 
@@ -331,7 +331,14 @@ main (argc,argv)
       while(resu_syr_entete(version,&nt,temps+npdt)>0)
 	{
 	  npdt++;
-	  sprintf(nomnum,"%.4d",npdt);
+
+	  /* attention : dimension max du tableau 'temps' en dur */
+	  if (npdt>100000){
+	    printf("\n  Impossible to convert more than 100000 time steps \n");
+	    exit(1);
+	  }
+
+	  sprintf(nomnum,"%.5d",npdt);
 	  
 	  i=0;
 	  while(resu_syr_nomvar(&nbre,nomvar[i],discr+i)==1)
@@ -341,7 +348,7 @@ main (argc,argv)
 	      strncat(nomfichvar,".",1);
 	      strncat(nomfichvar,nomvar[i],strlen(nomvar[i]));
 	      strncat(nomfichvar,".",1);
-	      strncat(nomfichvar,nomnum,4);
+	      strncat(nomfichvar,nomnum,5);
 	      
 	      var=(double*)malloc(nbre*sizeof(double));
 	      resu_syr_var(nbre,var);
@@ -388,10 +395,10 @@ main (argc,argv)
       for (i=0;i<nbscal;i++)
 	{
 	  if (discr[i]==3)
-	    fprintf(fcase,"scalar per node: 1     %s        %s.%s.****\n",
+	    fprintf(fcase,"scalar per node: 1     %s        %s.%s.*****\n",
 		    nomvar[i],nombase,nomvar[i]);
 	  else if (discr[i]==2) 
-	    fprintf(fcase,"scalar per element: 1     %s        %s.%s.****\n",
+	    fprintf(fcase,"scalar per element: 1     %s        %s.%s.*****\n",
 		    nomvar[i],nombase,nomvar[i]);
 	}      
       fprintf(fcase,"TIME\n");
@@ -435,7 +442,7 @@ void entete(rp_int *ndim,rp_int *ndiele,rp_int *npoin,rp_int *nelem,rp_int *nbno
 
   fgets(ch,90,fsyrg);
 
-    /* entete version 4.1 */
+    /* entete version 4.3 */
     if (!strncmp(ch,"C*V4.0",6))
       {
 	*version=40;
@@ -643,7 +650,7 @@ void combien_scalaires(FILE *fsyrr,rp_int *nbscal,rp_int *npoin,rp_int *nelem,rp
   /* determination de la version du fichier */
   fgets(ch,90,fsyrr);
 
-  /* entete version 4.1 */
+  /* entete version 4.3 */
   if (!strncmp(ch,"*V4.0",5))
     {
       *version=40;
